package info.aspirecn.rdc.iov.sjjh.servicenode.supplier.service.impl;

import java.io.IOException;
import java.net.SocketTimeoutException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.concurrent.TimeUnit;
import java.util.regex.Pattern;

import javax.servlet.http.HttpServletRequest;
import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import info.aspirecn.iov.sjjh.commons.lang.PatternTools;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.constant.SjjhConstants;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.vo.*;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.vo.CarHistoricalTrajectoryResponseObject.CarHistoricalTrajectoryResponseDetails;

import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.time.DateFormatUtils;
import org.apache.commons.lang3.time.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.exc.UnrecognizedPropertyException;

import info.aspirecn.iov.sjjh.commons.lang.ChannelTypeHandleResponseObject;
import info.aspirecn.iov.sjjh.commons.lang.Constant;
import info.aspirecn.iov.sjjh.commons.lang.Md5Util;
import info.aspirecn.rdc.aspirecloud.node.except.utils.ErrorUtils;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.enums.DigestALGEnum;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.service.CarService;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.utils.ApiDigestUtil;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.utils.DesUtils;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.utils.RxUtil;
import info.aspirecn.rdc.iov.sjjh.servicenode.supplier.utils.SjjhConstant;
import lombok.extern.slf4j.Slf4j;
import okhttp3.MediaType;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;

@Slf4j
@Service
public class CarServiceImpl implements CarService {

    /**
     * yyyy-mm正则表达式
     */
    private static final String DATE_YYYYMMDD = "^((19|20)[0-9]{2})-(0?[1-9]|1[012])$";

    @Value("${supplier.vTranCapaAsseUrl}")
    private String vTranCapaAsseUrl;

    @Value("${supplier.cTranCapaAsseUrl}")
    private String cTranCapaAsseUrl;
    @Value("${supplier.uid}")
    private String uid;
    @Value("${supplier.key}")
    private String key;
    @Value("${supplier.baiduUrl}")
	private String baiduUrl;
    @Value("${supplier.baiduAk}")
	private String baiduAk;
    @Value("${supplier.vehicleTrajectoryQueryUrl}")
    private String vehicleTrajectoryQueryUrl;
    @Value("${supplier.lastPositionUrl}")
    private String lastPositionUrl;
    @Value("${supplier.truckExistCheck}")
    private String truckExistCheck;
    @Value("${supplier.carsLastPositionUrl}")
    private String carsLastPositionUrl;
    @Value("${supplier.enterpriseQuery}")
    private String enterpriseQuery;
    @Value("${supplier.personQuery}")
    private String personQuery;
    @Value("${supplier.vehicleQuery}")
    private String vehicleQuery;
    @Value("${supplier.carOwnerRealness}")
    private String carOwnerRealness;
    @Value("${supplier.carCondition}")
    private String carCondition;
    @Value("${supplier.carOperate}")
    private String carOperate;
    @Value("${supplier.carpictransportno}")
    private String carpictransportno;
    @Value("${supplier.vQueryMileage}")
    private String vQueryMileage;
    @Value("${supplier.vQueryPark}")
    private String vQueryPark;
    @Autowired
    private ObjectMapper objectMapper;

    private OkHttpClient okHttpClient = new OkHttpClient.Builder().build();

    @Autowired
    StringRedisTemplate stringRedisTemplate;

    @Override
    public ChannelTypeHandleResponseObject getCarCapacity(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject res = new ChannelTypeHandleResponseObject();
        String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        try {
            if (outTime <= 0) {
                outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
            }
            CarCapacityRequestObject jsonResolveObject = objectMapper.readValue(customBody,
                    CarCapacityRequestObject.class);
            if (DesUtils.checkParam(jsonResolveObject)) {
                res.setResultCode(Constant.INVALID_PARAMETER_CODE);
                res.setResultBody(Constant.INVALID_PARAMETER);
                res.setResultDesc(Constant.INVALID_PARAMETER);
                return res;
            }
            String responseContext = "";
            res.setIsCharge(Constant.IS_NOT_CHARGE);
            res.setCode(Constant.SUCCESS);
            //生成签名
            Map<String, String> map = new HashMap<>();
            map.put("vclN", jsonResolveObject.getVclN());
            map.put("month", jsonResolveObject.getMonth());
            map.put("vco", jsonResolveObject.getVco());
            map.put("uid", uid);
            String sign = ApiDigestUtil.execute(map, key, DigestALGEnum.MD5, "UTF-8");
            log.info("生成sign签名:{}", sign);
            map.put("sign", sign);
            MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
            String jsonStr = objectMapper.writeValueAsString(map);
            log.info("getCarCapacity请求上游参数:{}", jsonStr);
            RequestBody requestBody = RequestBody.create(mediaType, jsonStr);
            Request okRequest = new Request.Builder().post(requestBody).url(vTranCapaAsseUrl).build();
            OkHttpClient client = okHttpClient.newBuilder()
                    .sslSocketFactory(RxUtil.createSSLSocketFactory(), new RxUtil.TrustAllManager())
                    .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                    .readTimeout(outTime, TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime, TimeUnit.MILLISECONDS)
                    .build();
            Response response = client.newCall(okRequest).execute();
            responseContext = response.body().string();
            log.info("getCarCapacity返回结果:{}", responseContext);
            CarCapacityResponseObject responseObject = objectMapper.readValue(responseContext, CarCapacityResponseObject.class);
            if (responseObject == null) {
                res.setResultCode(Constant.OTHER_ERROR_CODE);
                res.setResultBody(Constant.OTHER_ERROR);
                res.setResultDesc(Constant.OTHER_ERROR);
            } else {
                upstreamCode = responseObject.getCode();
                if ("0000".equals(responseObject.getCode())) {
                    res.setResultCode(Constant.MATCH_CODE);
                    CarCapacityResponseObject.CarCapacityResponseChildObject data = responseObject.getData();
                    String result = objectMapper.writeValueAsString(data);
                    res.setResultBody(result);
                    res.setResultDesc(responseObject.getMsg());
                    res.setIsCharge(Constant.IS_CHARGE);
                } else if ("0001".equals(responseObject.getCode())) {
                    res.setResultCode(Constant.UN_FIND_NUM_CODE);
                    res.setResultBody(Constant.UN_FIND_NUM);
                    res.setResultDesc(Constant.UN_FIND_NUM);
                } else if ("1002".equals(responseObject.getCode())) {
                    res.setResultCode(Constant.INVALID_PARAMETER_CODE);
                    res.setResultBody(Constant.INVALID_PARAMETER);
                    res.setResultDesc(Constant.INVALID_PARAMETER);
                } else {
                    res.setResultCode(Constant.OTHER_ERROR_CODE);
                    res.setResultBody(Constant.OTHER_ERROR);
                    res.setResultDesc(Constant.OTHER_ERROR);
                }
            }
            request.setAttribute(SjjhConstant.Charge_Log_Up_ResponseCode, upstreamCode);
            return res;
        } catch (IOException e) {
            ErrorUtils.captureException(e);
            log.error("IOException,message:{}", e);
            res.setCode(Constant.FAIL);
            return res;
        } catch (Exception e) {
            ErrorUtils.captureException(e);
            log.error("Exception,message:{}", e);
            res.setCode(Constant.FAIL);
            return res;
        }
    }

    @Override
    public ChannelTypeHandleResponseObject carEnterpriseTransportInfoCheck(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setCode(Constant.SUCCESS);
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }

        Response response = null;
        String responseContext = "";
        try {
            if (outTime <= 0) {
                outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
            }

            log.info("supplier10000041-carEnterpriseTransportInfoCheck---customBody={},outTime={}", customBody, outTime);
            ObjectMapper mapper = new ObjectMapper();
            CarJsonResolveObject jsonObject = mapper.readValue(customBody,
                    CarJsonResolveObject.class);
            //公司名
            String companyName = jsonObject.getCompanyName();
            //查询日期
            String monthStr = jsonObject.getMonthStr();
            //校验参数
            Pattern pattern = Pattern.compile(DATE_YYYYMMDD);
            if (StringUtils.isBlank(companyName) ||
                    StringUtils.isBlank(monthStr) ||
                    !pattern.matcher(monthStr).matches()) {
                if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                    ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                } else {
                    ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                }

                ret.setResultDesc(Constant.INVALID_PARAMETER);
                ret.setResultBody(Constant.INVALID_PARAMETER);
                return ret;
            }

            String signStr = "comp=" + companyName + "&month=" + monthStr + "&uid=" + uid + key;
            String sign = Md5Util.encrypt32(signStr).toLowerCase();
            CarRequestObject requestObject = new CarRequestObject();
            requestObject.setComp(companyName);
            requestObject.setMonth(monthStr);
            requestObject.setSign(sign);
            requestObject.setUid(uid);
            //生成签名
            /*Map<String, String> map = new HashMap<>();
            map.put("comp", jsonObject.getCompanyName());
            map.put("month", jsonObject.getMonthStr());
            map.put("uid", uid);
            String sign=ApiDigestUtil.execute(map, key, DigestALGEnum.MD5, "UTF-8");
            log.info("生成sign签名:{}",sign);
            map.put("sign", sign);*/
            MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
            String jsonStr = objectMapper.writeValueAsString(requestObject);
            //String jsonStr = objectMapper.writeValueAsString(map);
            log.info("supplier10000041-carEnterpriseTransportInfoCheck---jsonStr={}", jsonStr);
            RequestBody requestBody = RequestBody.create(mediaType, jsonStr);

            Request okRequest = new Request.Builder().post(requestBody).url(cTranCapaAsseUrl).build();
            OkHttpClient client = okHttpClient.newBuilder()
                    .sslSocketFactory(RxUtil.createSSLSocketFactory(), new RxUtil.TrustAllManager())
                    .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                    .readTimeout(outTime, TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime, TimeUnit.MILLISECONDS)
                    .build();
            response = client.newCall(okRequest).execute();
            responseContext = response.body().string();
            log.info("supplier10000041-carEnterpriseTransportInfoCheck调接口后的返回:{}", responseContext);
            CarResponseObject reponseObject = mapper.readValue(responseContext,
                    CarResponseObject.class);
            if (reponseObject != null) {
                upstreamCode = reponseObject.getCode();
            }

            ret = setcarEnterpriseTransportInfoResponse(ret, returnType, reponseObject);
        } catch (SocketTimeoutException ste) {
            ErrorUtils.captureException(ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch (UnrecognizedPropertyException upe) {
            log.info("supplier10000041-carEnterpriseTransportInfoCheck-UnrecognizedPropertyException：{}", upe);
            ErrorUtils.captureException(upe);
            ret.setCode(Constant.SUCCESS);
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            /**参数错误*/
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_9909);
            } else {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
            ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            return ret;
        } catch (IOException ioe) {
            ErrorUtils.captureException(ioe);
            ret.setCode(Constant.FAIL);
        }

        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    /**
     * 设置车企动信息的返回码
     *
     * @param ret
     * @param returnType
     * @param reponseObject
     */
    private ChannelTypeHandleResponseObject setcarEnterpriseTransportInfoResponse(
            ChannelTypeHandleResponseObject ret,
            String returnType, CarResponseObject reponseObject) {
        if (reponseObject != null
                && "0000".equals(reponseObject.getCode())) {
            // 查询成功，返回结果
            ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
            ret.setResultBody(reponseObject.getData());

            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
            } else {
                ret.setResultCode(Constant.MATCH_CODE);
            }
        } else if (reponseObject != null
                && "0001".equals(reponseObject.getCode())) {
            // 查询成功，没有记录
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
            } else {
                ret.setResultCode(Constant.UN_FIND_NUM_CODE);
            }
            ret.setResultBody(Constant.RETURN_MESSAGE_60);
            ret.setResultDesc(Constant.RETURN_MESSAGE_60);
        } else {
            // 查询错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
            } else {
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
            }
            ret.setResultBody(Constant.OTHER_ERROR);
            ret.setResultDesc(Constant.OTHER_ERROR);
        }

        return ret;
    }

    @Override
    public ChannelTypeHandleResponseObject carHistoricalTrajectoryQuery(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        if (outTime <= SjjhConstants.PARA_ZERO) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }
        log.info("supplier10000041.carHistoricalTrajectoryQuery---customBody={},outTime={}", customBody, outTime);
        try {
            CarHistoricalTrajectoryRequestObject requestObject = objectMapper.readValue(customBody,
                    CarHistoricalTrajectoryRequestObject.class);
            log.info("supplier10000041.carHistoricalTrajectoryQuery---requestObject={}", requestObject);
            // 参数校验
            if (!validateRequestParams(ret, returnType, requestObject)) {
                ret.setCode(Constant.SUCCESS);
                request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
                return ret;
            }

            //生成签名
            Map<String, String> map = new HashMap<>();
            map.put("vclN", requestObject.getPlateNum());
            map.put("qryBtm", DateFormatUtils.format(DateUtils.parseDate(requestObject.getStartTime(), SjjhConstants.TIME_FORMAT), SjjhConstants.DATE_FORMAT));
            map.put("qryEtm", DateFormatUtils.format(DateUtils.parseDate(requestObject.getEndTime(), SjjhConstants.TIME_FORMAT), SjjhConstants.DATE_FORMAT));
            map.put("uid", uid);
            String sign = ApiDigestUtil.execute(map, key, DigestALGEnum.MD5, "UTF-8");
            log.info("生成sign签名:{}", sign);
            map.put("sign", sign);
            MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
            String jsonStr = objectMapper.writeValueAsString(map);
            log.info("carHistoricalTrajectoryQuery请求上游参数:{}", jsonStr);

            RequestBody requestBody = RequestBody.create(mediaType, jsonStr);
            Request okRequest = new Request.Builder().post(requestBody).url(vehicleTrajectoryQueryUrl).build();
            OkHttpClient client = okHttpClient.newBuilder()
                    .sslSocketFactory(RxUtil.createSSLSocketFactory(), new RxUtil.TrustAllManager())
                    .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                    .readTimeout(outTime, TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime, TimeUnit.MILLISECONDS)
                    .build();
            Response response = client.newCall(okRequest).execute();
            String responseContext = response.body().string();

            log.info("carHistoricalTrajectoryQuery返回结果:{}", responseContext);
            CarHistoricalTrajectoryResponseObject responseObject = objectMapper.readValue(responseContext,
                    CarHistoricalTrajectoryResponseObject.class);
            response.close();

            if (responseObject != null) {
                upstreamCode = responseObject.getCode();
                ret.setCode(Constant.SUCCESS);
                setCarHistoricalTrajectoryResponse(ret, returnType, responseObject);
                if (ret.getIsCharge() == Constant.IS_CHARGE) {
                    chargeHandle(request, ret, requestObject);
                }
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            log.info("supplier10000041.carHistoricalTrajectoryQuery接口-SocketTimeoutException：{}", ste);
            ErrorUtils.captureException(ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch (Exception ioe) {
            log.info("supplier10000041.carHistoricalTrajectoryQuery接口-Exception：{}", ioe);
            ErrorUtils.captureException(ioe);
            ret.setCode(Constant.FAIL);
        }
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }
    @Override
	public ChannelTypeHandleResponseObject carHistoricalTrajectoryQueryByBaidu(HttpServletRequest request,
			String customBody, int outTime) {
		ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
		ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
		ret.setCode(Constant.SUCCESS);
		String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
		request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
		String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
		if (StringUtils.isBlank(returnType)) {
			returnType = Constant.CUSTOMER_RETURN_ZW;
		}
		if (outTime <= SjjhConstants.PARA_ZERO) {
			outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
		}
		log.info("supplier10000041.carHistoricalTrajectoryQueryByBaidu---customBody={},outTime={}", customBody, outTime);
		try {
			GeocodingJsonResolveObject jsonResolveObject = objectMapper.readValue(customBody,
					GeocodingJsonResolveObject.class);
			log.info("supplier10000041.carHistoricalTrajectoryQueryByBaidu---requestObject={}", jsonResolveObject);
			String vehicleNumber = jsonResolveObject.getVehicleNumber();
			String dateTime = jsonResolveObject.getDateTime();
			String countrySubdivisionCode = jsonResolveObject.getCountrySubdivisionCode();
			List<String> list=new ArrayList<String>();
			// 参数校验
			Pattern pattern = Pattern.compile(SjjhConstants.TIME_REGEX);
			if (StringUtils.isBlank(vehicleNumber)||!PatternTools.checkResult(Constant.PATTERN_CAR_NUMBER_REGEX, vehicleNumber)) {
				list.add("vehicleNumber");
			}
			if (StringUtils.isBlank(dateTime)||!pattern.matcher(dateTime).matches()) {
				list.add("dateTime");
			}
			if (StringUtils.isBlank(countrySubdivisionCode)||!countrySubdivisionCode.matches("[0-9]{6}")) {
				list.add("countrySubdivisionCode");
			}
			if (list.size()>0) {
				ResultBody resultBody = new ResultBody();
				resultBody.setCode(3);
				resultBody.setResultList(list);
				ret.setResultBody(resultBody);
                if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                    ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                } else {
                    ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                }
                ret.setResultDesc(Constant.INVALID_PARAMETER);
				return ret;
			}
			//生成签名
            SimpleDateFormat simpleDateFormat = new SimpleDateFormat(SjjhConstants.TIME_FORMAT);
            Date starTime =simpleDateFormat.parse(adjustTime(dateTime,-2));
            Date endTime = simpleDateFormat.parse(adjustTime(dateTime,2));
			Map<String, String> map = new HashMap<>();
			map.put("vclN", jsonResolveObject.getVehicleNumber());
			map.put("qryBtm", DateFormatUtils.format(starTime, SjjhConstants.DATE_FORMAT));
			map.put("qryEtm", DateFormatUtils.format(endTime, SjjhConstants.DATE_FORMAT));
			map.put("uid", uid);
			String sign=ApiDigestUtil.execute(map, key, DigestALGEnum.MD5, "UTF-8");
			log.info("生成sign签名:{}",sign);
			map.put("sign", sign);
			MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
			String jsonStr = objectMapper.writeValueAsString(map);
			log.info("carHistoricalTrajectoryQueryByBaidu请求上游参数:{}",jsonStr);

			RequestBody requestBody = RequestBody.create(mediaType, jsonStr);
			Request okRequest = new Request.Builder().post(requestBody).url(vehicleTrajectoryQueryUrl).build();
			OkHttpClient client = okHttpClient.newBuilder()
					.sslSocketFactory(RxUtil.createSSLSocketFactory(), new RxUtil.TrustAllManager())
					.connectTimeout(outTime, TimeUnit.MILLISECONDS)
					.readTimeout(outTime, TimeUnit.MILLISECONDS)
					.writeTimeout(outTime, TimeUnit.MILLISECONDS)
					.build();
			Response response = client.newCall(okRequest).execute();
			String responseContext = response.body().string();
            //String responseContext ="{\"code\":\"0000\",\"data\":{\"infos\":[{\"queryTime\":\"2019-08-01\",\"trackDetails\":[{\"agl\":\"0\",\"gtm\":\"20190801/192141\",\"hgt\":\"0\",\"lat\":\"17668610\",\"lon\":\"63904593\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/192212\",\"hgt\":\"0\",\"lat\":\"17668610\",\"lon\":\"63904593\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"177\",\"gtm\":\"20190801/192243\",\"hgt\":\"193\",\"lat\":\"17668639\",\"lon\":\"63904627\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"177\",\"gtm\":\"20190801/192313\",\"hgt\":\"192\",\"lat\":\"17668610\",\"lon\":\"63904617\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"177\",\"gtm\":\"20190801/192342\",\"hgt\":\"192\",\"lat\":\"17668610\",\"lon\":\"63904617\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"177\",\"gtm\":\"20190801/192412\",\"hgt\":\"202\",\"lat\":\"17668629\",\"lon\":\"63904627\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"274\",\"gtm\":\"20190801/192442\",\"hgt\":\"201\",\"lat\":\"17668629\",\"lon\":\"63904627\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"274\",\"gtm\":\"20190801/192512\",\"hgt\":\"201\",\"lat\":\"17668629\",\"lon\":\"63904627\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"138\",\"gtm\":\"20190801/192542\",\"hgt\":\"198\",\"lat\":\"17668629\",\"lon\":\"63904641\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"131\",\"gtm\":\"20190801/192612\",\"hgt\":\"199\",\"lat\":\"17668620\",\"lon\":\"63904641\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"131\",\"gtm\":\"20190801/192642\",\"hgt\":\"198\",\"lat\":\"17668620\",\"lon\":\"63904651\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"80\",\"gtm\":\"20190801/192712\",\"hgt\":\"198\",\"lat\":\"17668620\",\"lon\":\"63904651\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"176\",\"gtm\":\"20190801/192742\",\"hgt\":\"198\",\"lat\":\"17668599\",\"lon\":\"63904651\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"203\",\"gtm\":\"20190801/192813\",\"hgt\":\"198\",\"lat\":\"17668599\",\"lon\":\"63904651\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"204\",\"gtm\":\"20190801/192842\",\"hgt\":\"196\",\"lat\":\"17668590\",\"lon\":\"63904641\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"4\",\"gtm\":\"20190801/192912\",\"hgt\":\"196\",\"lat\":\"17668590\",\"lon\":\"63904641\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"4\",\"gtm\":\"20190801/192942\",\"hgt\":\"198\",\"lat\":\"17668639\",\"lon\":\"63904617\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"255\",\"gtm\":\"20190801/193012\",\"hgt\":\"198\",\"lat\":\"17668660\",\"lon\":\"63904627\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"255\",\"gtm\":\"20190801/193042\",\"hgt\":\"198\",\"lat\":\"17668660\",\"lon\":\"63904627\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"255\",\"gtm\":\"20190801/193112\",\"hgt\":\"198\",\"lat\":\"17668660\",\"lon\":\"63904627\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"255\",\"gtm\":\"20190801/193142\",\"hgt\":\"198\",\"lat\":\"17668660\",\"lon\":\"63904627\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"255\",\"gtm\":\"20190801/193212\",\"hgt\":\"198\",\"lat\":\"17668660\",\"lon\":\"63904627\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"255\",\"gtm\":\"20190801/193242\",\"hgt\":\"198\",\"lat\":\"17668660\",\"lon\":\"63904627\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"255\",\"gtm\":\"20190801/193312\",\"hgt\":\"198\",\"lat\":\"17668660\",\"lon\":\"63904627\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"255\",\"gtm\":\"20190801/193342\",\"hgt\":\"198\",\"lat\":\"17668660\",\"lon\":\"63904627\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"255\",\"gtm\":\"20190801/193412\",\"hgt\":\"198\",\"lat\":\"17668660\",\"lon\":\"63904627\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"255\",\"gtm\":\"20190801/193442\",\"hgt\":\"198\",\"lat\":\"17668660\",\"lon\":\"63904627\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"1\",\"gtm\":\"20190801/193512\",\"hgt\":\"211\",\"lat\":\"17668650\",\"lon\":\"63904617\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"19\",\"gtm\":\"20190801/193542\",\"hgt\":\"210\",\"lat\":\"17668660\",\"lon\":\"63904617\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"299\",\"gtm\":\"20190801/193612\",\"hgt\":\"212\",\"lat\":\"17668669\",\"lon\":\"63904641\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"299\",\"gtm\":\"20190801/193643\",\"hgt\":\"216\",\"lat\":\"17668669\",\"lon\":\"63904641\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"160\",\"gtm\":\"20190801/193713\",\"hgt\":\"216\",\"lat\":\"17668680\",\"lon\":\"63904641\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"97\",\"gtm\":\"20190801/193742\",\"hgt\":\"217\",\"lat\":\"17668700\",\"lon\":\"63904660\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"97\",\"gtm\":\"20190801/193812\",\"hgt\":\"217\",\"lat\":\"17668700\",\"lon\":\"63904660\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"97\",\"gtm\":\"20190801/193842\",\"hgt\":\"219\",\"lat\":\"17668710\",\"lon\":\"63904651\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"97\",\"gtm\":\"20190801/193912\",\"hgt\":\"219\",\"lat\":\"17668700\",\"lon\":\"63904651\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"97\",\"gtm\":\"20190801/193942\",\"hgt\":\"219\",\"lat\":\"17668700\",\"lon\":\"63904651\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/194317\",\"hgt\":\"0\",\"lat\":\"17668700\",\"lon\":\"63904651\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/194348\",\"hgt\":\"0\",\"lat\":\"17668700\",\"lon\":\"63904651\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"61\",\"gtm\":\"20190801/194417\",\"hgt\":\"185\",\"lat\":\"17668700\",\"lon\":\"63904651\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"61\",\"gtm\":\"20190801/194449\",\"hgt\":\"202\",\"lat\":\"17668639\",\"lon\":\"63904660\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"61\",\"gtm\":\"20190801/194519\",\"hgt\":\"202\",\"lat\":\"17668639\",\"lon\":\"63904660\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"61\",\"gtm\":\"20190801/194547\",\"hgt\":\"202\",\"lat\":\"17668639\",\"lon\":\"63904660\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"46\",\"gtm\":\"20190801/194617\",\"hgt\":\"209\",\"lat\":\"17668639\",\"lon\":\"63904660\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"252\",\"gtm\":\"20190801/194647\",\"hgt\":\"208\",\"lat\":\"17668639\",\"lon\":\"63904651\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"252\",\"gtm\":\"20190801/194717\",\"hgt\":\"208\",\"lat\":\"17668639\",\"lon\":\"63904651\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"260\",\"gtm\":\"20190801/194747\",\"hgt\":\"208\",\"lat\":\"17668639\",\"lon\":\"63904651\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"113\",\"gtm\":\"20190801/194817\",\"hgt\":\"207\",\"lat\":\"17668629\",\"lon\":\"63904641\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"280\",\"gtm\":\"20190801/194847\",\"hgt\":\"207\",\"lat\":\"17668639\",\"lon\":\"63904627\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"255\",\"gtm\":\"20190801/194917\",\"hgt\":\"206\",\"lat\":\"17668629\",\"lon\":\"63904617\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"90\",\"gtm\":\"20190801/194947\",\"hgt\":\"205\",\"lat\":\"17668629\",\"lon\":\"63904608\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"242\",\"gtm\":\"20190801/195017\",\"hgt\":\"203\",\"lat\":\"17668629\",\"lon\":\"63904598\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"92\",\"gtm\":\"20190801/195047\",\"hgt\":\"203\",\"lat\":\"17668629\",\"lon\":\"63904598\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"247\",\"gtm\":\"20190801/195117\",\"hgt\":\"203\",\"lat\":\"17668639\",\"lon\":\"63904598\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"287\",\"gtm\":\"20190801/195147\",\"hgt\":\"204\",\"lat\":\"17668610\",\"lon\":\"63904651\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"287\",\"gtm\":\"20190801/195218\",\"hgt\":\"204\",\"lat\":\"17668610\",\"lon\":\"63904651\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"23\",\"gtm\":\"20190801/195248\",\"hgt\":\"206\",\"lat\":\"17668620\",\"lon\":\"63904670\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"123\",\"gtm\":\"20190801/195317\",\"hgt\":\"211\",\"lat\":\"17668620\",\"lon\":\"63904680\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"123\",\"gtm\":\"20190801/195347\",\"hgt\":\"211\",\"lat\":\"17668620\",\"lon\":\"63904680\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"123\",\"gtm\":\"20190801/195417\",\"hgt\":\"211\",\"lat\":\"17668620\",\"lon\":\"63904680\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"121\",\"gtm\":\"20190801/195447\",\"hgt\":\"215\",\"lat\":\"17668599\",\"lon\":\"63904660\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"51\",\"gtm\":\"20190801/195517\",\"hgt\":\"220\",\"lat\":\"17668590\",\"lon\":\"63904627\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"322\",\"gtm\":\"20190801/195547\",\"hgt\":\"219\",\"lat\":\"17668590\",\"lon\":\"63904627\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"322\",\"gtm\":\"20190801/195617\",\"hgt\":\"217\",\"lat\":\"17668580\",\"lon\":\"63904641\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"120\",\"gtm\":\"20190801/195647\",\"hgt\":\"219\",\"lat\":\"17668590\",\"lon\":\"63904617\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"50\",\"gtm\":\"20190801/195717\",\"hgt\":\"218\",\"lat\":\"17668590\",\"lon\":\"63904627\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"264\",\"gtm\":\"20190801/195747\",\"hgt\":\"217\",\"lat\":\"17668590\",\"lon\":\"63904641\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"80\",\"gtm\":\"20190801/195817\",\"hgt\":\"219\",\"lat\":\"17668610\",\"lon\":\"63904627\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"88\",\"gtm\":\"20190801/195847\",\"hgt\":\"222\",\"lat\":\"17668599\",\"lon\":\"63904608\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"286\",\"gtm\":\"20190801/195917\",\"hgt\":\"223\",\"lat\":\"17668599\",\"lon\":\"63904641\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"286\",\"gtm\":\"20190801/195947\",\"hgt\":\"223\",\"lat\":\"17668599\",\"lon\":\"63904641\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"286\",\"gtm\":\"20190801/200017\",\"hgt\":\"223\",\"lat\":\"17668599\",\"lon\":\"63904641\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"286\",\"gtm\":\"20190801/200047\",\"hgt\":\"223\",\"lat\":\"17668599\",\"lon\":\"63904641\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"307\",\"gtm\":\"20190801/200118\",\"hgt\":\"219\",\"lat\":\"17668620\",\"lon\":\"63904598\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"205\",\"gtm\":\"20190801/200156\",\"hgt\":\"216\",\"lat\":\"17668590\",\"lon\":\"63904627\",\"mlg\":\"42643\",\"spd\":\"0\"},{\"agl\":\"102\",\"gtm\":\"20190801/200225\",\"hgt\":\"215\",\"lat\":\"17668329\",\"lon\":\"63904790\",\"mlg\":\"42644\",\"spd\":\"0\"},{\"agl\":\"41\",\"gtm\":\"20190801/200255\",\"hgt\":\"221\",\"lat\":\"17668419\",\"lon\":\"63905059\",\"mlg\":\"42644\",\"spd\":\"70\"},{\"agl\":\"60\",\"gtm\":\"20190801/200325\",\"hgt\":\"219\",\"lat\":\"17668740\",\"lon\":\"63905731\",\"mlg\":\"42645\",\"spd\":\"210\"},{\"agl\":\"48\",\"gtm\":\"20190801/200355\",\"hgt\":\"218\",\"lat\":\"17669209\",\"lon\":\"63906676\",\"mlg\":\"42647\",\"spd\":\"270\"},{\"agl\":\"17\",\"gtm\":\"20190801/200425\",\"hgt\":\"227\",\"lat\":\"17669500\",\"lon\":\"63907209\",\"mlg\":\"42649\",\"spd\":\"210\"},{\"agl\":\"14\",\"gtm\":\"20190801/200455\",\"hgt\":\"242\",\"lat\":\"17670279\",\"lon\":\"63908121\",\"mlg\":\"42651\",\"spd\":\"220\"},{\"agl\":\"55\",\"gtm\":\"20190801/200525\",\"hgt\":\"248\",\"lat\":\"17670980\",\"lon\":\"63908280\",\"mlg\":\"42652\",\"spd\":\"250\"},{\"agl\":\"50\",\"gtm\":\"20190801/200555\",\"hgt\":\"253\",\"lat\":\"17671579\",\"lon\":\"63909158\",\"mlg\":\"42654\",\"spd\":\"210\"},{\"agl\":\"49\",\"gtm\":\"20190801/200625\",\"hgt\":\"259\",\"lat\":\"17671800\",\"lon\":\"63909508\",\"mlg\":\"42655\",\"spd\":\"0\"},{\"agl\":\"30\",\"gtm\":\"20190801/200655\",\"hgt\":\"261\",\"lat\":\"17671809\",\"lon\":\"63909523\",\"mlg\":\"42655\",\"spd\":\"0\"},{\"agl\":\"249\",\"gtm\":\"20190801/200725\",\"hgt\":\"258\",\"lat\":\"17671800\",\"lon\":\"63909470\",\"mlg\":\"42655\",\"spd\":\"0\"},{\"agl\":\"316\",\"gtm\":\"20190801/200755\",\"hgt\":\"236\",\"lat\":\"17672580\",\"lon\":\"63908712\",\"mlg\":\"42657\",\"spd\":\"490\"},{\"agl\":\"58\",\"gtm\":\"20190801/200825\",\"hgt\":\"226\",\"lat\":\"17673660\",\"lon\":\"63908630\",\"mlg\":\"42660\",\"spd\":\"310\"},{\"agl\":\"314\",\"gtm\":\"20190801/200855\",\"hgt\":\"235\",\"lat\":\"17674390\",\"lon\":\"63909432\",\"mlg\":\"42662\",\"spd\":\"170\"},{\"agl\":\"309\",\"gtm\":\"20190801/200925\",\"hgt\":\"232\",\"lat\":\"17675010\",\"lon\":\"63908476\",\"mlg\":\"42664\",\"spd\":\"240\"},{\"agl\":\"9\",\"gtm\":\"20190801/200955\",\"hgt\":\"242\",\"lat\":\"17675859\",\"lon\":\"63908467\",\"mlg\":\"42666\",\"spd\":\"230\"},{\"agl\":\"40\",\"gtm\":\"20190801/201026\",\"hgt\":\"238\",\"lat\":\"17676879\",\"lon\":\"63907958\",\"mlg\":\"42668\",\"spd\":\"200\"},{\"agl\":\"56\",\"gtm\":\"20190801/201106\",\"hgt\":\"230\",\"lat\":\"17677309\",\"lon\":\"63908856\",\"mlg\":\"42670\",\"spd\":\"0\"},{\"agl\":\"44\",\"gtm\":\"20190801/201135\",\"hgt\":\"227\",\"lat\":\"17677290\",\"lon\":\"63908856\",\"mlg\":\"42670\",\"spd\":\"0\"},{\"agl\":\"357\",\"gtm\":\"20190801/201205\",\"hgt\":\"225\",\"lat\":\"17678190\",\"lon\":\"63908889\",\"mlg\":\"42672\",\"spd\":\"250\"},{\"agl\":\"353\",\"gtm\":\"20190801/201235\",\"hgt\":\"231\",\"lat\":\"17678420\",\"lon\":\"63908880\",\"mlg\":\"42672\",\"spd\":\"0\"},{\"agl\":\"5\",\"gtm\":\"20190801/201305\",\"hgt\":\"232\",\"lat\":\"17678499\",\"lon\":\"63908899\",\"mlg\":\"42672\",\"spd\":\"120\"},{\"agl\":\"0\",\"gtm\":\"20190801/201335\",\"hgt\":\"234\",\"lat\":\"17679540\",\"lon\":\"63908832\",\"mlg\":\"42674\",\"spd\":\"240\"},{\"agl\":\"359\",\"gtm\":\"20190801/201405\",\"hgt\":\"232\",\"lat\":\"17680089\",\"lon\":\"63908841\",\"mlg\":\"42675\",\"spd\":\"0\"},{\"agl\":\"356\",\"gtm\":\"20190801/201435\",\"hgt\":\"231\",\"lat\":\"17680590\",\"lon\":\"63908846\",\"mlg\":\"42676\",\"spd\":\"290\"},{\"agl\":\"327\",\"gtm\":\"20190801/201505\",\"hgt\":\"236\",\"lat\":\"17681859\",\"lon\":\"63908544\",\"mlg\":\"42679\",\"spd\":\"320\"},{\"agl\":\"307\",\"gtm\":\"20190801/201535\",\"hgt\":\"251\",\"lat\":\"17682490\",\"lon\":\"63907656\",\"mlg\":\"42681\",\"spd\":\"290\"},{\"agl\":\"316\",\"gtm\":\"20190801/201605\",\"hgt\":\"231\",\"lat\":\"17683269\",\"lon\":\"63906518\",\"mlg\":\"42683\",\"spd\":\"240\"},{\"agl\":\"29\",\"gtm\":\"20190801/201635\",\"hgt\":\"230\",\"lat\":\"17683809\",\"lon\":\"63906249\",\"mlg\":\"42684\",\"spd\":\"60\"},{\"agl\":\"47\",\"gtm\":\"20190801/201705\",\"hgt\":\"234\",\"lat\":\"17683869\",\"lon\":\"63906542\",\"mlg\":\"42685\",\"spd\":\"70\"},{\"agl\":\"157\",\"gtm\":\"20190801/201735\",\"hgt\":\"229\",\"lat\":\"17683909\",\"lon\":\"63906768\",\"mlg\":\"42685\",\"spd\":\"0\"},{\"agl\":\"10\",\"gtm\":\"20190801/201805\",\"hgt\":\"228\",\"lat\":\"17683900\",\"lon\":\"63906768\",\"mlg\":\"42685\",\"spd\":\"0\"},{\"agl\":\"329\",\"gtm\":\"20190801/201835\",\"hgt\":\"229\",\"lat\":\"17683930\",\"lon\":\"63906763\",\"mlg\":\"42685\",\"spd\":\"0\"},{\"agl\":\"279\",\"gtm\":\"20190801/201905\",\"hgt\":\"227\",\"lat\":\"17683950\",\"lon\":\"63906672\",\"mlg\":\"42685\",\"spd\":\"0\"},{\"agl\":\"328\",\"gtm\":\"20190801/201936\",\"hgt\":\"229\",\"lat\":\"17683980\",\"lon\":\"63906787\",\"mlg\":\"42685\",\"spd\":\"0\"},{\"agl\":\"195\",\"gtm\":\"20190801/202015\",\"hgt\":\"231\",\"lat\":\"17683989\",\"lon\":\"63906787\",\"mlg\":\"42685\",\"spd\":\"0\"},{\"agl\":\"268\",\"gtm\":\"20190801/202044\",\"hgt\":\"231\",\"lat\":\"17683989\",\"lon\":\"63906787\",\"mlg\":\"42685\",\"spd\":\"0\"},{\"agl\":\"268\",\"gtm\":\"20190801/202114\",\"hgt\":\"231\",\"lat\":\"17683989\",\"lon\":\"63906787\",\"mlg\":\"42685\",\"spd\":\"0\"},{\"agl\":\"268\",\"gtm\":\"20190801/202144\",\"hgt\":\"231\",\"lat\":\"17683989\",\"lon\":\"63906787\",\"mlg\":\"42685\",\"spd\":\"0\"},{\"agl\":\"268\",\"gtm\":\"20190801/202214\",\"hgt\":\"231\",\"lat\":\"17683989\",\"lon\":\"63906787\",\"mlg\":\"42685\",\"spd\":\"0\"},{\"agl\":\"268\",\"gtm\":\"20190801/202244\",\"hgt\":\"231\",\"lat\":\"17683989\",\"lon\":\"63906787\",\"mlg\":\"42685\",\"spd\":\"0\"},{\"agl\":\"95\",\"gtm\":\"20190801/202314\",\"hgt\":\"231\",\"lat\":\"17683989\",\"lon\":\"63906787\",\"mlg\":\"42685\",\"spd\":\"0\"},{\"agl\":\"1\",\"gtm\":\"20190801/202344\",\"hgt\":\"230\",\"lat\":\"17683989\",\"lon\":\"63906787\",\"mlg\":\"42685\",\"spd\":\"0\"},{\"agl\":\"1\",\"gtm\":\"20190801/202414\",\"hgt\":\"230\",\"lat\":\"17683989\",\"lon\":\"63906787\",\"mlg\":\"42685\",\"spd\":\"0\"},{\"agl\":\"155\",\"gtm\":\"20190801/202444\",\"hgt\":\"232\",\"lat\":\"17683930\",\"lon\":\"63906777\",\"mlg\":\"42685\",\"spd\":\"70\"},{\"agl\":\"188\",\"gtm\":\"20190801/202514\",\"hgt\":\"232\",\"lat\":\"17683680\",\"lon\":\"63906912\",\"mlg\":\"42685\",\"spd\":\"60\"},{\"agl\":\"40\",\"gtm\":\"20190801/202544\",\"hgt\":\"233\",\"lat\":\"17683719\",\"lon\":\"63906921\",\"mlg\":\"42685\",\"spd\":\"0\"},{\"agl\":\"51\",\"gtm\":\"20190801/202614\",\"hgt\":\"233\",\"lat\":\"17683740\",\"lon\":\"63906979\",\"mlg\":\"42685\",\"spd\":\"0\"},{\"agl\":\"344\",\"gtm\":\"20190801/202644\",\"hgt\":\"236\",\"lat\":\"17683780\",\"lon\":\"63906998\",\"mlg\":\"42685\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/203702\",\"hgt\":\"0\",\"lat\":\"17683710\",\"lon\":\"63906940\",\"mlg\":\"42684\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/203733\",\"hgt\":\"0\",\"lat\":\"17683710\",\"lon\":\"63906940\",\"mlg\":\"42684\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/203802\",\"hgt\":\"0\",\"lat\":\"17683710\",\"lon\":\"63906940\",\"mlg\":\"42684\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/203832\",\"hgt\":\"0\",\"lat\":\"17683710\",\"lon\":\"63906940\",\"mlg\":\"42684\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/203902\",\"hgt\":\"0\",\"lat\":\"17683710\",\"lon\":\"63906940\",\"mlg\":\"42684\",\"spd\":\"0\"},{\"agl\":\"96\",\"gtm\":\"20190801/203934\",\"hgt\":\"236\",\"lat\":\"17683820\",\"lon\":\"63906398\",\"mlg\":\"42684\",\"spd\":\"0\"},{\"agl\":\"268\",\"gtm\":\"20190801/204004\",\"hgt\":\"234\",\"lat\":\"17683770\",\"lon\":\"63906360\",\"mlg\":\"42684\",\"spd\":\"0\"},{\"agl\":\"270\",\"gtm\":\"20190801/204033\",\"hgt\":\"232\",\"lat\":\"17683750\",\"lon\":\"63906398\",\"mlg\":\"42684\",\"spd\":\"0\"},{\"agl\":\"126\",\"gtm\":\"20190801/204103\",\"hgt\":\"231\",\"lat\":\"17683730\",\"lon\":\"63906417\",\"mlg\":\"42684\",\"spd\":\"0\"},{\"agl\":\"305\",\"gtm\":\"20190801/204133\",\"hgt\":\"231\",\"lat\":\"17683700\",\"lon\":\"63906432\",\"mlg\":\"42684\",\"spd\":\"0\"},{\"agl\":\"135\",\"gtm\":\"20190801/204203\",\"hgt\":\"234\",\"lat\":\"17683700\",\"lon\":\"63906340\",\"mlg\":\"42684\",\"spd\":\"0\"},{\"agl\":\"8\",\"gtm\":\"20190801/204233\",\"hgt\":\"235\",\"lat\":\"17683759\",\"lon\":\"63906273\",\"mlg\":\"42684\",\"spd\":\"60\"},{\"agl\":\"1\",\"gtm\":\"20190801/204303\",\"hgt\":\"239\",\"lat\":\"17684200\",\"lon\":\"63906278\",\"mlg\":\"42685\",\"spd\":\"0\"},{\"agl\":\"349\",\"gtm\":\"20190801/204333\",\"hgt\":\"243\",\"lat\":\"17685289\",\"lon\":\"63906148\",\"mlg\":\"42688\",\"spd\":\"210\"},{\"agl\":\"348\",\"gtm\":\"20190801/204403\",\"hgt\":\"217\",\"lat\":\"17686370\",\"lon\":\"63905918\",\"mlg\":\"42690\",\"spd\":\"290\"},{\"agl\":\"358\",\"gtm\":\"20190801/204433\",\"hgt\":\"216\",\"lat\":\"17687169\",\"lon\":\"63905683\",\"mlg\":\"42692\",\"spd\":\"120\"},{\"agl\":\"27\",\"gtm\":\"20190801/204503\",\"hgt\":\"196\",\"lat\":\"17687760\",\"lon\":\"63905817\",\"mlg\":\"42693\",\"spd\":\"180\"},{\"agl\":\"83\",\"gtm\":\"20190801/204533\",\"hgt\":\"184\",\"lat\":\"17688250\",\"lon\":\"63906561\",\"mlg\":\"42695\",\"spd\":\"260\"},{\"agl\":\"106\",\"gtm\":\"20190801/204604\",\"hgt\":\"179\",\"lat\":\"17688030\",\"lon\":\"63908299\",\"mlg\":\"42698\",\"spd\":\"390\"},{\"agl\":\"136\",\"gtm\":\"20190801/204634\",\"hgt\":\"189\",\"lat\":\"17687229\",\"lon\":\"63909902\",\"mlg\":\"42701\",\"spd\":\"210\"},{\"agl\":\"138\",\"gtm\":\"20190801/204703\",\"hgt\":\"183\",\"lat\":\"17686899\",\"lon\":\"63910348\",\"mlg\":\"42702\",\"spd\":\"110\"},{\"agl\":\"144\",\"gtm\":\"20190801/204733\",\"hgt\":\"173\",\"lat\":\"17686050\",\"lon\":\"63911328\",\"mlg\":\"42704\",\"spd\":\"350\"},{\"agl\":\"145\",\"gtm\":\"20190801/204803\",\"hgt\":\"178\",\"lat\":\"17684960\",\"lon\":\"63912192\",\"mlg\":\"42707\",\"spd\":\"0\"},{\"agl\":\"133\",\"gtm\":\"20190801/204833\",\"hgt\":\"181\",\"lat\":\"17684840\",\"lon\":\"63912350\",\"mlg\":\"42707\",\"spd\":\"150\"},{\"agl\":\"120\",\"gtm\":\"20190801/204903\",\"hgt\":\"185\",\"lat\":\"17684439\",\"lon\":\"63913190\",\"mlg\":\"42709\",\"spd\":\"140\"},{\"agl\":\"130\",\"gtm\":\"20190801/204933\",\"hgt\":\"171\",\"lat\":\"17683630\",\"lon\":\"63914548\",\"mlg\":\"42712\",\"spd\":\"450\"},{\"agl\":\"76\",\"gtm\":\"20190801/205003\",\"hgt\":\"172\",\"lat\":\"17683179\",\"lon\":\"63916699\",\"mlg\":\"42716\",\"spd\":\"450\"},{\"agl\":\"91\",\"gtm\":\"20190801/205033\",\"hgt\":\"189\",\"lat\":\"17683730\",\"lon\":\"63918580\",\"mlg\":\"42719\",\"spd\":\"310\"},{\"agl\":\"95\",\"gtm\":\"20190801/205103\",\"hgt\":\"197\",\"lat\":\"17683620\",\"lon\":\"63919468\",\"mlg\":\"42721\",\"spd\":\"230\"},{\"agl\":\"101\",\"gtm\":\"20190801/205133\",\"hgt\":\"192\",\"lat\":\"17683029\",\"lon\":\"63921048\",\"mlg\":\"42723\",\"spd\":\"390\"},{\"agl\":\"71\",\"gtm\":\"20190801/205203\",\"hgt\":\"183\",\"lat\":\"17683230\",\"lon\":\"63923073\",\"mlg\":\"42727\",\"spd\":\"0\"},{\"agl\":\"47\",\"gtm\":\"20190801/205233\",\"hgt\":\"182\",\"lat\":\"17683740\",\"lon\":\"63925478\",\"mlg\":\"42732\",\"spd\":\"400\"},{\"agl\":\"14\",\"gtm\":\"20190801/205303\",\"hgt\":\"180\",\"lat\":\"17684919\",\"lon\":\"63926121\",\"mlg\":\"42735\",\"spd\":\"320\"},{\"agl\":\"80\",\"gtm\":\"20190801/205333\",\"hgt\":\"180\",\"lat\":\"17685800\",\"lon\":\"63927182\",\"mlg\":\"42738\",\"spd\":\"330\"},{\"agl\":\"52\",\"gtm\":\"20190801/205403\",\"hgt\":\"183\",\"lat\":\"17686420\",\"lon\":\"63928761\",\"mlg\":\"42741\",\"spd\":\"350\"},{\"agl\":\"26\",\"gtm\":\"20190801/205433\",\"hgt\":\"184\",\"lat\":\"17687490\",\"lon\":\"63929784\",\"mlg\":\"42743\",\"spd\":\"360\"},{\"agl\":\"15\",\"gtm\":\"20190801/205504\",\"hgt\":\"182\",\"lat\":\"17689149\",\"lon\":\"63930432\",\"mlg\":\"42747\",\"spd\":\"350\"},{\"agl\":\"12\",\"gtm\":\"20190801/205543\",\"hgt\":\"189\",\"lat\":\"17691000\",\"lon\":\"63930888\",\"mlg\":\"42750\",\"spd\":\"300\"},{\"agl\":\"10\",\"gtm\":\"20190801/205612\",\"hgt\":\"178\",\"lat\":\"17692500\",\"lon\":\"63931190\",\"mlg\":\"42753\",\"spd\":\"380\"},{\"agl\":\"0\",\"gtm\":\"20190801/205642\",\"hgt\":\"179\",\"lat\":\"17693949\",\"lon\":\"63931718\",\"mlg\":\"42756\",\"spd\":\"350\"},{\"agl\":\"346\",\"gtm\":\"20190801/205712\",\"hgt\":\"177\",\"lat\":\"17694759\",\"lon\":\"63931579\",\"mlg\":\"42758\",\"spd\":\"0\"},{\"agl\":\"351\",\"gtm\":\"20190801/205742\",\"hgt\":\"186\",\"lat\":\"17694759\",\"lon\":\"63931579\",\"mlg\":\"42759\",\"spd\":\"0\"},{\"agl\":\"353\",\"gtm\":\"20190801/205812\",\"hgt\":\"186\",\"lat\":\"17699040\",\"lon\":\"63930772\",\"mlg\":\"42767\",\"spd\":\"150\"},{\"agl\":\"348\",\"gtm\":\"20190801/205842\",\"hgt\":\"187\",\"lat\":\"17700010\",\"lon\":\"63930552\",\"mlg\":\"42769\",\"spd\":\"240\"},{\"agl\":\"351\",\"gtm\":\"20190801/205912\",\"hgt\":\"186\",\"lat\":\"17701140\",\"lon\":\"63930321\",\"mlg\":\"42771\",\"spd\":\"190\"},{\"agl\":\"123\",\"gtm\":\"20190801/205942\",\"hgt\":\"193\",\"lat\":\"17701070\",\"lon\":\"63930950\",\"mlg\":\"42772\",\"spd\":\"160\"},{\"agl\":\"117\",\"gtm\":\"20190801/210012\",\"hgt\":\"198\",\"lat\":\"17700679\",\"lon\":\"63931862\",\"mlg\":\"42774\",\"spd\":\"220\"},{\"agl\":\"109\",\"gtm\":\"20190801/210042\",\"hgt\":\"208\",\"lat\":\"17700150\",\"lon\":\"63933009\",\"mlg\":\"42776\",\"spd\":\"300\"},{\"agl\":\"95\",\"gtm\":\"20190801/210112\",\"hgt\":\"223\",\"lat\":\"17699930\",\"lon\":\"63933998\",\"mlg\":\"42778\",\"spd\":\"70\"},{\"agl\":\"104\",\"gtm\":\"20190801/210142\",\"hgt\":\"217\",\"lat\":\"17699829\",\"lon\":\"63934488\",\"mlg\":\"42779\",\"spd\":\"90\"},{\"agl\":\"0\",\"gtm\":\"20190801/213052\",\"hgt\":\"0\",\"lat\":\"17699810\",\"lon\":\"63934560\",\"mlg\":\"42779\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/213123\",\"hgt\":\"0\",\"lat\":\"17699810\",\"lon\":\"63934560\",\"mlg\":\"42779\",\"spd\":\"0\"},{\"agl\":\"306\",\"gtm\":\"20190801/213152\",\"hgt\":\"0\",\"lat\":\"17699810\",\"lon\":\"63934560\",\"mlg\":\"42779\",\"spd\":\"0\"},{\"agl\":\"71\",\"gtm\":\"20190801/213224\",\"hgt\":\"230\",\"lat\":\"17700050\",\"lon\":\"63937060\",\"mlg\":\"42780\",\"spd\":\"210\"},{\"agl\":\"72\",\"gtm\":\"20190801/213254\",\"hgt\":\"252\",\"lat\":\"17700240\",\"lon\":\"63938059\",\"mlg\":\"42782\",\"spd\":\"200\"},{\"agl\":\"98\",\"gtm\":\"20190801/213322\",\"hgt\":\"263\",\"lat\":\"17700289\",\"lon\":\"63939081\",\"mlg\":\"42784\",\"spd\":\"190\"},{\"agl\":\"96\",\"gtm\":\"20190801/213352\",\"hgt\":\"276\",\"lat\":\"17700019\",\"lon\":\"63939888\",\"mlg\":\"42785\",\"spd\":\"140\"},{\"agl\":\"13\",\"gtm\":\"20190801/213422\",\"hgt\":\"284\",\"lat\":\"17700720\",\"lon\":\"63940310\",\"mlg\":\"42786\",\"spd\":\"200\"},{\"agl\":\"16\",\"gtm\":\"20190801/213452\",\"hgt\":\"294\",\"lat\":\"17701299\",\"lon\":\"63940430\",\"mlg\":\"42787\",\"spd\":\"110\"},{\"agl\":\"331\",\"gtm\":\"20190801/213522\",\"hgt\":\"294\",\"lat\":\"17701549\",\"lon\":\"63940497\",\"mlg\":\"42788\",\"spd\":\"0\"},{\"agl\":\"322\",\"gtm\":\"20190801/213552\",\"hgt\":\"296\",\"lat\":\"17701560\",\"lon\":\"63940488\",\"mlg\":\"42788\",\"spd\":\"0\"},{\"agl\":\"11\",\"gtm\":\"20190801/213622\",\"hgt\":\"291\",\"lat\":\"17701890\",\"lon\":\"63940569\",\"mlg\":\"42788\",\"spd\":\"300\"},{\"agl\":\"20\",\"gtm\":\"20190801/213652\",\"hgt\":\"274\",\"lat\":\"17702450\",\"lon\":\"63940809\",\"mlg\":\"42789\",\"spd\":\"0\"},{\"agl\":\"71\",\"gtm\":\"20190801/213722\",\"hgt\":\"268\",\"lat\":\"17702389\",\"lon\":\"63941668\",\"mlg\":\"42791\",\"spd\":\"0\"},{\"agl\":\"20\",\"gtm\":\"20190801/213752\",\"hgt\":\"264\",\"lat\":\"17702380\",\"lon\":\"63941702\",\"mlg\":\"42791\",\"spd\":\"0\"},{\"agl\":\"14\",\"gtm\":\"20190801/213822\",\"hgt\":\"257\",\"lat\":\"17702409\",\"lon\":\"63941923\",\"mlg\":\"42791\",\"spd\":\"110\"},{\"agl\":\"12\",\"gtm\":\"20190801/213852\",\"hgt\":\"272\",\"lat\":\"17703279\",\"lon\":\"63942192\",\"mlg\":\"42793\",\"spd\":\"270\"},{\"agl\":\"355\",\"gtm\":\"20190801/213922\",\"hgt\":\"284\",\"lat\":\"17704700\",\"lon\":\"63942321\",\"mlg\":\"42796\",\"spd\":\"310\"},{\"agl\":\"340\",\"gtm\":\"20190801/213953\",\"hgt\":\"289\",\"lat\":\"17705479\",\"lon\":\"63942168\",\"mlg\":\"42797\",\"spd\":\"130\"},{\"agl\":\"5\",\"gtm\":\"20190801/214023\",\"hgt\":\"270\",\"lat\":\"17706700\",\"lon\":\"63942230\",\"mlg\":\"42799\",\"spd\":\"260\"},{\"agl\":\"14\",\"gtm\":\"20190801/214052\",\"hgt\":\"269\",\"lat\":\"17708260\",\"lon\":\"63942537\",\"mlg\":\"42802\",\"spd\":\"330\"},{\"agl\":\"91\",\"gtm\":\"20190801/214122\",\"hgt\":\"269\",\"lat\":\"17709360\",\"lon\":\"63943171\",\"mlg\":\"42805\",\"spd\":\"190\"},{\"agl\":\"47\",\"gtm\":\"20190801/214152\",\"hgt\":\"268\",\"lat\":\"17709300\",\"lon\":\"63943929\",\"mlg\":\"42806\",\"spd\":\"0\"},{\"agl\":\"77\",\"gtm\":\"20190801/214222\",\"hgt\":\"269\",\"lat\":\"17709270\",\"lon\":\"63944011\",\"mlg\":\"42806\",\"spd\":\"0\"},{\"agl\":\"92\",\"gtm\":\"20190801/214252\",\"hgt\":\"273\",\"lat\":\"17709270\",\"lon\":\"63944510\",\"mlg\":\"42807\",\"spd\":\"130\"},{\"agl\":\"65\",\"gtm\":\"20190801/214322\",\"hgt\":\"274\",\"lat\":\"17709410\",\"lon\":\"63945518\",\"mlg\":\"42809\",\"spd\":\"200\"},{\"agl\":\"96\",\"gtm\":\"20190801/214352\",\"hgt\":\"280\",\"lat\":\"17709350\",\"lon\":\"63946459\",\"mlg\":\"42810\",\"spd\":\"180\"},{\"agl\":\"39\",\"gtm\":\"20190801/214422\",\"hgt\":\"290\",\"lat\":\"17709710\",\"lon\":\"63947020\",\"mlg\":\"42811\",\"spd\":\"130\"},{\"agl\":\"75\",\"gtm\":\"20190801/214452\",\"hgt\":\"303\",\"lat\":\"17710080\",\"lon\":\"63947529\",\"mlg\":\"42812\",\"spd\":\"140\"},{\"agl\":\"94\",\"gtm\":\"20190801/214522\",\"hgt\":\"311\",\"lat\":\"17710010\",\"lon\":\"63948220\",\"mlg\":\"42814\",\"spd\":\"130\"},{\"agl\":\"164\",\"gtm\":\"20190801/214552\",\"hgt\":\"322\",\"lat\":\"17709909\",\"lon\":\"63948878\",\"mlg\":\"42815\",\"spd\":\"120\"},{\"agl\":\"269\",\"gtm\":\"20190801/214622\",\"hgt\":\"324\",\"lat\":\"17709720\",\"lon\":\"63948369\",\"mlg\":\"42816\",\"spd\":\"110\"},{\"agl\":\"179\",\"gtm\":\"20190801/214652\",\"hgt\":\"334\",\"lat\":\"17709420\",\"lon\":\"63947952\",\"mlg\":\"42817\",\"spd\":\"110\"},{\"agl\":\"153\",\"gtm\":\"20190801/214722\",\"hgt\":\"343\",\"lat\":\"17708919\",\"lon\":\"63948240\",\"mlg\":\"42818\",\"spd\":\"130\"},{\"agl\":\"150\",\"gtm\":\"20190801/214752\",\"hgt\":\"355\",\"lat\":\"17708499\",\"lon\":\"63948768\",\"mlg\":\"42819\",\"spd\":\"120\"},{\"agl\":\"194\",\"gtm\":\"20190801/214822\",\"hgt\":\"369\",\"lat\":\"17707920\",\"lon\":\"63948667\",\"mlg\":\"42820\",\"spd\":\"120\"},{\"agl\":\"184\",\"gtm\":\"20190801/214853\",\"hgt\":\"386\",\"lat\":\"17707310\",\"lon\":\"63948518\",\"mlg\":\"42821\",\"spd\":\"130\"},{\"agl\":\"149\",\"gtm\":\"20190801/214931\",\"hgt\":\"399\",\"lat\":\"17706240\",\"lon\":\"63948379\",\"mlg\":\"42823\",\"spd\":\"240\"},{\"agl\":\"93\",\"gtm\":\"20190801/215000\",\"hgt\":\"396\",\"lat\":\"17706530\",\"lon\":\"63948787\",\"mlg\":\"42824\",\"spd\":\"0\"},{\"agl\":\"93\",\"gtm\":\"20190801/215030\",\"hgt\":\"398\",\"lat\":\"17706540\",\"lon\":\"63948777\",\"mlg\":\"42824\",\"spd\":\"0\"},{\"agl\":\"10\",\"gtm\":\"20190801/215100\",\"hgt\":\"389\",\"lat\":\"17706740\",\"lon\":\"63948849\",\"mlg\":\"42825\",\"spd\":\"0\"},{\"agl\":\"10\",\"gtm\":\"20190801/215130\",\"hgt\":\"389\",\"lat\":\"17706780\",\"lon\":\"63948864\",\"mlg\":\"42825\",\"spd\":\"0\"},{\"agl\":\"114\",\"gtm\":\"20190801/215200\",\"hgt\":\"389\",\"lat\":\"17706780\",\"lon\":\"63948864\",\"mlg\":\"42825\",\"spd\":\"0\"},{\"agl\":\"276\",\"gtm\":\"20190801/215230\",\"hgt\":\"389\",\"lat\":\"17706780\",\"lon\":\"63948864\",\"mlg\":\"42825\",\"spd\":\"0\"},{\"agl\":\"101\",\"gtm\":\"20190801/215300\",\"hgt\":\"386\",\"lat\":\"17706780\",\"lon\":\"63948868\",\"mlg\":\"42825\",\"spd\":\"0\"},{\"agl\":\"81\",\"gtm\":\"20190801/215330\",\"hgt\":\"385\",\"lat\":\"17706780\",\"lon\":\"63948868\",\"mlg\":\"42825\",\"spd\":\"0\"},{\"agl\":\"80\",\"gtm\":\"20190801/215400\",\"hgt\":\"383\",\"lat\":\"17706780\",\"lon\":\"63948868\",\"mlg\":\"42825\",\"spd\":\"0\"},{\"agl\":\"286\",\"gtm\":\"20190801/215430\",\"hgt\":\"381\",\"lat\":\"17706780\",\"lon\":\"63948878\",\"mlg\":\"42825\",\"spd\":\"0\"},{\"agl\":\"97\",\"gtm\":\"20190801/215500\",\"hgt\":\"379\",\"lat\":\"17706780\",\"lon\":\"63948888\",\"mlg\":\"42825\",\"spd\":\"0\"},{\"agl\":\"295\",\"gtm\":\"20190801/215530\",\"hgt\":\"378\",\"lat\":\"17706780\",\"lon\":\"63948878\",\"mlg\":\"42825\",\"spd\":\"0\"},{\"agl\":\"12\",\"gtm\":\"20190801/215600\",\"hgt\":\"378\",\"lat\":\"17706840\",\"lon\":\"63948912\",\"mlg\":\"42825\",\"spd\":\"0\"},{\"agl\":\"323\",\"gtm\":\"20190801/215630\",\"hgt\":\"386\",\"lat\":\"17706960\",\"lon\":\"63948912\",\"mlg\":\"42825\",\"spd\":\"0\"},{\"agl\":\"346\",\"gtm\":\"20190801/215700\",\"hgt\":\"390\",\"lat\":\"17706960\",\"lon\":\"63948912\",\"mlg\":\"42825\",\"spd\":\"0\"},{\"agl\":\"343\",\"gtm\":\"20190801/215730\",\"hgt\":\"397\",\"lat\":\"17706960\",\"lon\":\"63948912\",\"mlg\":\"42825\",\"spd\":\"0\"},{\"agl\":\"24\",\"gtm\":\"20190801/215801\",\"hgt\":\"398\",\"lat\":\"17706950\",\"lon\":\"63948912\",\"mlg\":\"42825\",\"spd\":\"0\"},{\"agl\":\"35\",\"gtm\":\"20190801/215840\",\"hgt\":\"402\",\"lat\":\"17707020\",\"lon\":\"63948940\",\"mlg\":\"42825\",\"spd\":\"0\"},{\"agl\":\"64\",\"gtm\":\"20190801/215909\",\"hgt\":\"399\",\"lat\":\"17707320\",\"lon\":\"63949080\",\"mlg\":\"42825\",\"spd\":\"70\"},{\"agl\":\"23\",\"gtm\":\"20190801/215939\",\"hgt\":\"391\",\"lat\":\"17707670\",\"lon\":\"63949478\",\"mlg\":\"42826\",\"spd\":\"90\"},{\"agl\":\"89\",\"gtm\":\"20190801/220009\",\"hgt\":\"404\",\"lat\":\"17708110\",\"lon\":\"63949708\",\"mlg\":\"42827\",\"spd\":\"120\"},{\"agl\":\"208\",\"gtm\":\"20190801/220039\",\"hgt\":\"416\",\"lat\":\"17707650\",\"lon\":\"63949723\",\"mlg\":\"42828\",\"spd\":\"110\"},{\"agl\":\"196\",\"gtm\":\"20190801/220109\",\"hgt\":\"434\",\"lat\":\"17707100\",\"lon\":\"63949468\",\"mlg\":\"42829\",\"spd\":\"130\"},{\"agl\":\"152\",\"gtm\":\"20190801/220139\",\"hgt\":\"433\",\"lat\":\"17706380\",\"lon\":\"63949651\",\"mlg\":\"42830\",\"spd\":\"150\"},{\"agl\":\"152\",\"gtm\":\"20190801/220209\",\"hgt\":\"430\",\"lat\":\"17705749\",\"lon\":\"63950011\",\"mlg\":\"42832\",\"spd\":\"90\"},{\"agl\":\"158\",\"gtm\":\"20190801/220239\",\"hgt\":\"428\",\"lat\":\"17705690\",\"lon\":\"63950020\",\"mlg\":\"42832\",\"spd\":\"0\"},{\"agl\":\"211\",\"gtm\":\"20190801/220309\",\"hgt\":\"430\",\"lat\":\"17705679\",\"lon\":\"63950011\",\"mlg\":\"42832\",\"spd\":\"0\"},{\"agl\":\"165\",\"gtm\":\"20190801/220339\",\"hgt\":\"435\",\"lat\":\"17705649\",\"lon\":\"63950001\",\"mlg\":\"42832\",\"spd\":\"0\"},{\"agl\":\"100\",\"gtm\":\"20190801/220409\",\"hgt\":\"429\",\"lat\":\"17705570\",\"lon\":\"63950212\",\"mlg\":\"42832\",\"spd\":\"70\"},{\"agl\":\"20\",\"gtm\":\"20190801/220439\",\"hgt\":\"432\",\"lat\":\"17705719\",\"lon\":\"63950443\",\"mlg\":\"42832\",\"spd\":\"60\"},{\"agl\":\"264\",\"gtm\":\"20190801/220509\",\"hgt\":\"434\",\"lat\":\"17705760\",\"lon\":\"63950433\",\"mlg\":\"42832\",\"spd\":\"0\"},{\"agl\":\"132\",\"gtm\":\"20190801/220539\",\"hgt\":\"437\",\"lat\":\"17705749\",\"lon\":\"63950448\",\"mlg\":\"42832\",\"spd\":\"0\"},{\"agl\":\"307\",\"gtm\":\"20190801/220609\",\"hgt\":\"437\",\"lat\":\"17705749\",\"lon\":\"63950443\",\"mlg\":\"42832\",\"spd\":\"0\"},{\"agl\":\"13\",\"gtm\":\"20190801/220639\",\"hgt\":\"436\",\"lat\":\"17705740\",\"lon\":\"63950443\",\"mlg\":\"42832\",\"spd\":\"0\"},{\"agl\":\"15\",\"gtm\":\"20190801/220710\",\"hgt\":\"441\",\"lat\":\"17706110\",\"lon\":\"63950568\",\"mlg\":\"42833\",\"spd\":\"100\"},{\"agl\":\"26\",\"gtm\":\"20190801/220750\",\"hgt\":\"461\",\"lat\":\"17706900\",\"lon\":\"63951168\",\"mlg\":\"42835\",\"spd\":\"160\"},{\"agl\":\"130\",\"gtm\":\"20190801/220819\",\"hgt\":\"464\",\"lat\":\"17706979\",\"lon\":\"63951691\",\"mlg\":\"42836\",\"spd\":\"60\"},{\"agl\":\"182\",\"gtm\":\"20190801/220849\",\"hgt\":\"471\",\"lat\":\"17706390\",\"lon\":\"63951758\",\"mlg\":\"42837\",\"spd\":\"170\"},{\"agl\":\"150\",\"gtm\":\"20190801/220919\",\"hgt\":\"469\",\"lat\":\"17705700\",\"lon\":\"63951739\",\"mlg\":\"42838\",\"spd\":\"160\"},{\"agl\":\"192\",\"gtm\":\"20190801/220949\",\"hgt\":\"470\",\"lat\":\"17705220\",\"lon\":\"63952339\",\"mlg\":\"42840\",\"spd\":\"120\"},{\"agl\":\"143\",\"gtm\":\"20190801/221019\",\"hgt\":\"476\",\"lat\":\"17704759\",\"lon\":\"63952430\",\"mlg\":\"42841\",\"spd\":\"110\"},{\"agl\":\"171\",\"gtm\":\"20190801/221049\",\"hgt\":\"474\",\"lat\":\"17704350\",\"lon\":\"63952569\",\"mlg\":\"42841\",\"spd\":\"120\"},{\"agl\":\"179\",\"gtm\":\"20190801/221119\",\"hgt\":\"463\",\"lat\":\"17703799\",\"lon\":\"63952526\",\"mlg\":\"42842\",\"spd\":\"100\"},{\"agl\":\"171\",\"gtm\":\"20190801/221149\",\"hgt\":\"453\",\"lat\":\"17703270\",\"lon\":\"63952512\",\"mlg\":\"42843\",\"spd\":\"90\"},{\"agl\":\"177\",\"gtm\":\"20190801/221219\",\"hgt\":\"444\",\"lat\":\"17702589\",\"lon\":\"63952550\",\"mlg\":\"42845\",\"spd\":\"140\"},{\"agl\":\"191\",\"gtm\":\"20190801/221249\",\"hgt\":\"432\",\"lat\":\"17702080\",\"lon\":\"63952579\",\"mlg\":\"42846\",\"spd\":\"0\"},{\"agl\":\"190\",\"gtm\":\"20190801/221320\",\"hgt\":\"430\",\"lat\":\"17701310\",\"lon\":\"63951926\",\"mlg\":\"42848\",\"spd\":\"180\"},{\"agl\":\"150\",\"gtm\":\"20190801/221350\",\"hgt\":\"426\",\"lat\":\"17700580\",\"lon\":\"63952300\",\"mlg\":\"42850\",\"spd\":\"180\"},{\"agl\":\"234\",\"gtm\":\"20190801/221419\",\"hgt\":\"416\",\"lat\":\"17699889\",\"lon\":\"63952046\",\"mlg\":\"42851\",\"spd\":\"150\"},{\"agl\":\"120\",\"gtm\":\"20190801/221449\",\"hgt\":\"402\",\"lat\":\"17699310\",\"lon\":\"63952046\",\"mlg\":\"42853\",\"spd\":\"240\"},{\"agl\":\"203\",\"gtm\":\"20190801/221519\",\"hgt\":\"401\",\"lat\":\"17698560\",\"lon\":\"63952368\",\"mlg\":\"42854\",\"spd\":\"200\"},{\"agl\":\"209\",\"gtm\":\"20190801/221549\",\"hgt\":\"409\",\"lat\":\"17697960\",\"lon\":\"63951628\",\"mlg\":\"42856\",\"spd\":\"180\"},{\"agl\":\"156\",\"gtm\":\"20190801/221620\",\"hgt\":\"412\",\"lat\":\"17697129\",\"lon\":\"63951489\",\"mlg\":\"42858\",\"spd\":\"200\"},{\"agl\":\"188\",\"gtm\":\"20190801/221659\",\"hgt\":\"407\",\"lat\":\"17696169\",\"lon\":\"63951268\",\"mlg\":\"42860\",\"spd\":\"210\"},{\"agl\":\"184\",\"gtm\":\"20190801/221728\",\"hgt\":\"402\",\"lat\":\"17695560\",\"lon\":\"63951158\",\"mlg\":\"42861\",\"spd\":\"150\"},{\"agl\":\"144\",\"gtm\":\"20190801/221758\",\"hgt\":\"406\",\"lat\":\"17694820\",\"lon\":\"63951523\",\"mlg\":\"42863\",\"spd\":\"140\"},{\"agl\":\"124\",\"gtm\":\"20190801/221828\",\"hgt\":\"396\",\"lat\":\"17694240\",\"lon\":\"63951912\",\"mlg\":\"42864\",\"spd\":\"160\"},{\"agl\":\"120\",\"gtm\":\"20190801/221858\",\"hgt\":\"393\",\"lat\":\"17693799\",\"lon\":\"63952838\",\"mlg\":\"42866\",\"spd\":\"200\"},{\"agl\":\"184\",\"gtm\":\"20190801/221928\",\"hgt\":\"384\",\"lat\":\"17692999\",\"lon\":\"63952958\",\"mlg\":\"42868\",\"spd\":\"180\"},{\"agl\":\"168\",\"gtm\":\"20190801/221958\",\"hgt\":\"387\",\"lat\":\"17692260\",\"lon\":\"63953049\",\"mlg\":\"42869\",\"spd\":\"210\"},{\"agl\":\"219\",\"gtm\":\"20190801/222028\",\"hgt\":\"380\",\"lat\":\"17691319\",\"lon\":\"63952713\",\"mlg\":\"42871\",\"spd\":\"260\"},{\"agl\":\"182\",\"gtm\":\"20190801/222058\",\"hgt\":\"385\",\"lat\":\"17690169\",\"lon\":\"63952228\",\"mlg\":\"42873\",\"spd\":\"310\"},{\"agl\":\"176\",\"gtm\":\"20190801/222128\",\"hgt\":\"379\",\"lat\":\"17689040\",\"lon\":\"63951926\",\"mlg\":\"42876\",\"spd\":\"70\"},{\"agl\":\"190\",\"gtm\":\"20190801/222158\",\"hgt\":\"380\",\"lat\":\"17688990\",\"lon\":\"63951921\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/223954\",\"hgt\":\"0\",\"lat\":\"17689029\",\"lon\":\"63951926\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/224025\",\"hgt\":\"0\",\"lat\":\"17689029\",\"lon\":\"63951926\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/224054\",\"hgt\":\"0\",\"lat\":\"17689029\",\"lon\":\"63951926\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"234\",\"gtm\":\"20190801/224124\",\"hgt\":\"0\",\"lat\":\"17689029\",\"lon\":\"63951926\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"132\",\"gtm\":\"20190801/224156\",\"hgt\":\"405\",\"lat\":\"17688219\",\"lon\":\"63952910\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/224246\",\"hgt\":\"0\",\"lat\":\"17688309\",\"lon\":\"63952857\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/224317\",\"hgt\":\"0\",\"lat\":\"17688309\",\"lon\":\"63952857\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"106\",\"gtm\":\"20190801/224346\",\"hgt\":\"0\",\"lat\":\"17688309\",\"lon\":\"63952857\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"101\",\"gtm\":\"20190801/224417\",\"hgt\":\"346\",\"lat\":\"17687940\",\"lon\":\"63953500\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/225953\",\"hgt\":\"0\",\"lat\":\"17688309\",\"lon\":\"63952857\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/230024\",\"hgt\":\"0\",\"lat\":\"17688309\",\"lon\":\"63952857\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"164\",\"gtm\":\"20190801/230053\",\"hgt\":\"0\",\"lat\":\"17688309\",\"lon\":\"63952857\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"175\",\"gtm\":\"20190801/230123\",\"hgt\":\"0\",\"lat\":\"17688309\",\"lon\":\"63952857\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"175\",\"gtm\":\"20190801/230154\",\"hgt\":\"377\",\"lat\":\"17687460\",\"lon\":\"63953952\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"162\",\"gtm\":\"20190801/230224\",\"hgt\":\"379\",\"lat\":\"17687289\",\"lon\":\"63954038\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"152\",\"gtm\":\"20190801/230253\",\"hgt\":\"386\",\"lat\":\"17687130\",\"lon\":\"63954110\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"169\",\"gtm\":\"20190801/230323\",\"hgt\":\"385\",\"lat\":\"17687030\",\"lon\":\"63954206\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"307\",\"gtm\":\"20190801/230353\",\"hgt\":\"378\",\"lat\":\"17686940\",\"lon\":\"63954091\",\"mlg\":\"42876\",\"spd\":\"60\"},{\"agl\":\"335\",\"gtm\":\"20190801/230423\",\"hgt\":\"389\",\"lat\":\"17687150\",\"lon\":\"63953937\",\"mlg\":\"42876\",\"spd\":\"60\"},{\"agl\":\"291\",\"gtm\":\"20190801/230453\",\"hgt\":\"393\",\"lat\":\"17687349\",\"lon\":\"63953793\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/230947\",\"hgt\":\"0\",\"lat\":\"17687250\",\"lon\":\"63953880\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/231018\",\"hgt\":\"0\",\"lat\":\"17687250\",\"lon\":\"63953880\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/231047\",\"hgt\":\"0\",\"lat\":\"17687250\",\"lon\":\"63953880\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/233144\",\"hgt\":\"0\",\"lat\":\"17687250\",\"lon\":\"63953880\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/233215\",\"hgt\":\"0\",\"lat\":\"17687250\",\"lon\":\"63953880\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/234339\",\"hgt\":\"0\",\"lat\":\"17687250\",\"lon\":\"63953880\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/234410\",\"hgt\":\"0\",\"lat\":\"17687250\",\"lon\":\"63953880\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"231\",\"gtm\":\"20190801/234441\",\"hgt\":\"414\",\"lat\":\"17686520\",\"lon\":\"63953116\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"354\",\"gtm\":\"20190801/234511\",\"hgt\":\"371\",\"lat\":\"17686470\",\"lon\":\"63953112\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"354\",\"gtm\":\"20190801/234539\",\"hgt\":\"372\",\"lat\":\"17686470\",\"lon\":\"63953102\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"354\",\"gtm\":\"20190801/234609\",\"hgt\":\"372\",\"lat\":\"17686470\",\"lon\":\"63953102\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"354\",\"gtm\":\"20190801/234639\",\"hgt\":\"372\",\"lat\":\"17686470\",\"lon\":\"63953102\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"222\",\"gtm\":\"20190801/234709\",\"hgt\":\"382\",\"lat\":\"17686470\",\"lon\":\"63953102\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"288\",\"gtm\":\"20190801/234739\",\"hgt\":\"384\",\"lat\":\"17686460\",\"lon\":\"63953059\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"288\",\"gtm\":\"20190801/234809\",\"hgt\":\"384\",\"lat\":\"17686460\",\"lon\":\"63953059\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"288\",\"gtm\":\"20190801/234839\",\"hgt\":\"384\",\"lat\":\"17686460\",\"lon\":\"63953059\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"151\",\"gtm\":\"20190801/234909\",\"hgt\":\"385\",\"lat\":\"17686420\",\"lon\":\"63953040\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"47\",\"gtm\":\"20190801/234939\",\"hgt\":\"385\",\"lat\":\"17686420\",\"lon\":\"63953040\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"85\",\"gtm\":\"20190801/235009\",\"hgt\":\"386\",\"lat\":\"17686420\",\"lon\":\"63953040\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"85\",\"gtm\":\"20190801/235039\",\"hgt\":\"386\",\"lat\":\"17686420\",\"lon\":\"63953040\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"85\",\"gtm\":\"20190801/235109\",\"hgt\":\"386\",\"lat\":\"17686420\",\"lon\":\"63953040\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"204\",\"gtm\":\"20190801/235139\",\"hgt\":\"386\",\"lat\":\"17686420\",\"lon\":\"63953040\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"26\",\"gtm\":\"20190801/235209\",\"hgt\":\"386\",\"lat\":\"17686420\",\"lon\":\"63953040\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"24\",\"gtm\":\"20190801/235240\",\"hgt\":\"387\",\"lat\":\"17686420\",\"lon\":\"63953040\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"7\",\"gtm\":\"20190801/235313\",\"hgt\":\"388\",\"lat\":\"17686389\",\"lon\":\"63953059\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"314\",\"gtm\":\"20190801/235342\",\"hgt\":\"390\",\"lat\":\"17686440\",\"lon\":\"63952948\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"275\",\"gtm\":\"20190801/235412\",\"hgt\":\"390\",\"lat\":\"17686449\",\"lon\":\"63952900\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"95\",\"gtm\":\"20190801/235442\",\"hgt\":\"391\",\"lat\":\"17686449\",\"lon\":\"63952910\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"244\",\"gtm\":\"20190801/235512\",\"hgt\":\"391\",\"lat\":\"17686460\",\"lon\":\"63952828\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"264\",\"gtm\":\"20190801/235542\",\"hgt\":\"390\",\"lat\":\"17686460\",\"lon\":\"63952814\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"264\",\"gtm\":\"20190801/235612\",\"hgt\":\"390\",\"lat\":\"17686460\",\"lon\":\"63952814\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"107\",\"gtm\":\"20190801/235642\",\"hgt\":\"390\",\"lat\":\"17686460\",\"lon\":\"63952848\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"110\",\"gtm\":\"20190801/235712\",\"hgt\":\"391\",\"lat\":\"17686470\",\"lon\":\"63952910\",\"mlg\":\"42876\",\"spd\":\"0\"},{\"agl\":\"59\",\"gtm\":\"20190801/235742\",\"hgt\":\"394\",\"lat\":\"17686429\",\"lon\":\"63953169\",\"mlg\":\"42876\",\"spd\":\"70\"},{\"agl\":\"33\",\"gtm\":\"20190801/235812\",\"hgt\":\"398\",\"lat\":\"17686690\",\"lon\":\"63953548\",\"mlg\":\"42876\",\"spd\":\"90\"},{\"agl\":\"358\",\"gtm\":\"20190801/235842\",\"hgt\":\"404\",\"lat\":\"17687030\",\"lon\":\"63953649\",\"mlg\":\"42877\",\"spd\":\"0\"},{\"agl\":\"21\",\"gtm\":\"20190801/235912\",\"hgt\":\"406\",\"lat\":\"17687060\",\"lon\":\"63953640\",\"mlg\":\"42877\",\"spd\":\"0\"},{\"agl\":\"0\",\"gtm\":\"20190801/235942\",\"hgt\":\"407\",\"lat\":\"17687070\",\"lon\":\"63953640\",\"mlg\":\"42877\",\"spd\":\"0\"}]}]},\"msg\":\"查询成功\",\"orderNo\":\"426250959429111808\"}";
            log.info("carHistoricalTrajectoryQueryByBaidu返回结果:{}",responseContext);

            CarHistoricalTrajectoryResponseObject responseObject = objectMapper.readValue(responseContext,
					CarHistoricalTrajectoryResponseObject.class);
			response.close();
			if(responseObject != null) {
				upstreamCode = responseObject.getCode();
				if ("0000".equals(responseObject.getCode())) {
					ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);

					CarHistoricalTrajectoryResponseObject.CarHistoricalTrajectoryResponseInfos responseInfos = responseObject.getData().getInfos().get(0);
					List<CarHistoricalTrajectoryResponseDetails> responseDetails = responseInfos.getTrackDetails();
					List<CarHistoricalTrajectoryResponseDetails> responseDetailsList=new ArrayList<CarHistoricalTrajectoryResponseDetails>();
					for (CarHistoricalTrajectoryResponseDetails data : responseDetails) {
							Date gtm = simpleDateFormat.parse(DateFormatUtils.format(DateUtils.parseDate(data.getGtm(), SjjhConstants.TIME_FORMAT_HHmmss),SjjhConstants.TIME_FORMAT));
						if (isEffectiveDate(gtm, starTime, endTime)) {
							responseDetailsList.add(data);
						}
					}
					if (!responseDetailsList.isEmpty()) {

                        for (int hours = -2;hours<2;hours++){
                            //每小时的起始时间
                            Date starOneTime =simpleDateFormat.parse(adjustTime(dateTime,hours));
                            Date endOneTime = simpleDateFormat.parse(adjustTime(dateTime,hours+1));
                            //每小时的数据
                            List<CarHistoricalTrajectoryResponseDetails> responseDetailsHourList = new ArrayList<CarHistoricalTrajectoryResponseDetails>();
                            for(CarHistoricalTrajectoryResponseDetails data:responseDetailsList){
                                Date gtm = simpleDateFormat.parse(DateFormatUtils.format(DateUtils.parseDate(data.getGtm(), SjjhConstants.TIME_FORMAT_HHmmss),SjjhConstants.TIME_FORMAT));
                                if (isEffectiveDate(gtm, starOneTime, endOneTime)) {
                                    responseDetailsHourList.add(data);
                                }
                            }
                            if (responseDetailsHourList.size()<=3) {
                                for (CarHistoricalTrajectoryResponseDetails data : responseDetailsHourList) {
                                    boolean check = getGeocodingCheck(outTime,Double.parseDouble(data.getLat())/600000.0+","+Double.parseDouble(data.getLon())/600000.0,jsonResolveObject.getCountrySubdivisionCode());
                                    if (check) {
                                        //数据一致响应
                                        if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                                            ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
                                            ret.setResultDesc(Constant.DRIVE_STATUS_QUERY_SUCCESS);
                                        } else {
                                            ret.setResultCode(Constant.MATCH_CODE);
                                            ret.setResultDesc("一致");
                                        }

                                        ret.setResultBody("一致");
                                        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
                                        return ret;
                                    }
                                }
                            }else {
                                String	latLonFirst=Double.parseDouble(responseDetailsHourList.get(0).getLat())/600000.0+","+Double.parseDouble(responseDetailsHourList.get(0).getLon())/600000.0;
                                String	latLonMiddle=Double.parseDouble(responseDetailsHourList.get(responseDetailsHourList.size()/2).getLat())/600000.0+","+Double.parseDouble(responseDetailsHourList.get(responseDetailsHourList.size()/2).getLon())/600000.0;
                                String	latLonLast=Double.parseDouble(responseDetailsHourList.get(responseDetailsHourList.size()-1).getLat())/600000.0+","+Double.parseDouble(responseDetailsHourList.get(responseDetailsHourList.size()-1).getLon())/600000.0;
                                boolean firstCheck = getGeocodingCheck(outTime,latLonFirst, jsonResolveObject.getCountrySubdivisionCode());
                                boolean middleCheck = getGeocodingCheck(outTime,latLonMiddle,jsonResolveObject.getCountrySubdivisionCode());
                                boolean lastCheck = getGeocodingCheck(outTime,latLonLast,jsonResolveObject.getCountrySubdivisionCode());
                                if (firstCheck||middleCheck||lastCheck) {
                                    //数据一致响应
                                    if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                                        ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
                                        ret.setResultDesc(Constant.DRIVE_STATUS_QUERY_SUCCESS);
                                    } else {
                                        ret.setResultCode(Constant.MATCH_CODE);
                                        ret.setResultDesc("一致");
                                    }

                                    ret.setResultBody("一致");
                                    request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
                                    return ret;
                                }
                            }
                        }
                        //如果未输出ret则数据不一致响应
                        if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                            ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
                            ret.setResultDesc(Constant.DRIVE_STATUS_QUERY_SUCCESS);
                        } else {
                            ret.setResultCode(Constant.UN_MATCH_CODE);
                            ret.setResultDesc("不一致");
                        }

                        ResultBody resultBody = new ResultBody();
                        list.add("countrySubdivisionCode");
                        resultBody.setCode(2);
                        resultBody.setResultList(list);
                        ret.setResultBody(resultBody);
					}else {
						//数据源为空响应
                        if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                            ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
                            ret.setResultDesc(Constant.DRIVE_STATUS_QUERY_SUCCESS);
                        } else {
                            ret.setResultCode(Constant.UN_MATCH_CODE);
                            ret.setResultDesc("不一致");
                        }

						ResultBody resultBody = new ResultBody();
						list.add("vehicleNumber");
						list.add("dateTime");
						list.add("countrySubdivisionCode");
						resultBody.setCode(1);
						resultBody.setResultList(list);
						ret.setResultBody(resultBody);
					}
				} else if ("0001".equals(responseObject.getCode())) {
				    //查询结果为空
                    if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                        ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
                    } else {
                        ret.setResultCode(Constant.UN_FIND_NUM_CODE);
                    }
                    ret.setResultDesc(Constant.DRIVE_STATUS_QUERY_NO_RESULT);
					ResultBody resultBody = new ResultBody();
					list.add("vehicleNumber");
					list.add("dateTime");
					list.add("countrySubdivisionCode");
					resultBody.setCode(1);
					resultBody.setResultList(list);
					ret.setResultBody(resultBody);
				}else if ("1002".equals(responseObject.getCode())) {
                    if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                        ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                    } else {
                        ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                    }
                    ret.setResultDesc(Constant.INVALID_PARAMETER);
					ResultBody resultBody = new ResultBody();
					resultBody.setCode(3);
					list.add("vehicleNumber");
					resultBody.setResultList(list);
					ret.setResultBody(resultBody);
				}else {
                    if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                        ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
                    } else {
                        ret.setResultCode(Constant.OTHER_ERROR_CODE);
                    }
                    ret.setResultDesc(Constant.OTHER_ERROR);
					ResultBody resultBody = new ResultBody();
					resultBody.setCode(3);
					list.add("vehicleNumber");
					list.add("dateTime");
					list.add("countrySubdivisionCode");
					resultBody.setResultList(list);
					//resultBody.setErrorinfo(responseObject.getMsg());
					ret.setResultBody(resultBody);
				}

			} else {
                if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                    ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
                } else {
                    ret.setResultCode(Constant.OTHER_ERROR_CODE);
                }
                ret.setResultDesc(Constant.OTHER_ERROR);
				ResultBody resultBody = new ResultBody();
				resultBody.setCode(3);
				list.add("vehicleNumber");
				list.add("dateTime");
				list.add("countrySubdivisionCode");
				resultBody.setResultList(list);
				//resultBody.setErrorinfo(Constant.OTHER_ERROR);
				ret.setResultBody(resultBody);

			}
		} catch (SocketTimeoutException ste) {
			log.info("supplier10000041.carHistoricalTrajectoryQueryByBaidu接口-SocketTimeoutException：{}", ste);
			ErrorUtils.captureException(ste);
			ret.setCode(Constant.REQUEST_TIMEOUT);
		} catch (Exception ioe) {
			log.info("supplier10000041.carHistoricalTrajectoryQueryByBaidu接口-Exception：{}", ioe);
			ErrorUtils.captureException(ioe);
			ret.setCode(Constant.FAIL);
		}
		request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
		return ret;
	}
    //计算指定时间范围
    private static  String  adjustTime(String dateTime,int hours) throws Exception  {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Calendar calendar = Calendar.getInstance();
        Date date = sdf.parse(dateTime);
        calendar.setTime(date);
        calendar.set(Calendar.HOUR_OF_DAY,calendar.get(Calendar.HOUR_OF_DAY) + hours);
        return sdf.format(calendar.getTime());
    }

    /**
     * 判断当前时间是否在[startTime, endTime]区间，注意时间格式要一致
     *
     * @param nowTime 当前时间
     * @param startTime 开始时间
     * @param endTime 结束时间
     * @return
     * @author jqlin
     */
    public static boolean isEffectiveDate(Date nowTime, Date startTime, Date endTime) {
        if (nowTime.getTime() == startTime.getTime()
                || nowTime.getTime() == endTime.getTime()) {
            return true;
        }

        Calendar date = Calendar.getInstance();
        date.setTime(nowTime);

        Calendar begin = Calendar.getInstance();
        begin.setTime(startTime);

        Calendar end = Calendar.getInstance();
        end.setTime(endTime);

        if (date.after(begin) && date.before(end)) {
            return true;
        } else {
            return false;
        }
    }
    /**
	 * 校验省区划代码是否一致
	 */
	private Boolean getGeocodingCheck(int outTime, String location,String adcode) {
		try {
			 ObjectMapper objectMapper = new ObjectMapper();
				String requestUrl = baiduUrl + "?ak="+ baiduAk + "&output=json&coordtype=wgs84ll&location=" + location;
				Request okRequest = new Request.Builder().get().url(requestUrl).build();
				OkHttpClient client = okHttpClient.newBuilder().connectTimeout(outTime, TimeUnit.MILLISECONDS)
						.readTimeout(outTime, TimeUnit.MILLISECONDS).writeTimeout(outTime, TimeUnit.MILLISECONDS).build();
				Response response = client.newCall(okRequest).execute();
				String responseContext = response.body().string();
				GeocodingResponseObject responseObject = objectMapper.readValue(responseContext,
						GeocodingResponseObject.class);
				log.info("supplier10000041.getGeocodingCheck.responseObject={}", responseContext);
				if (responseObject!=null) {
					if (responseObject.getStatus()==0&&adcode.equals(responseObject.getResult().getAddressComponent().getAdcode())) {
						return true;
					}
				}
				return false;
		} catch (Exception e) {
			ErrorUtils.captureException(e);
			log.info("supplier10000041.Exception.e={}", e);

		}
		return false;
	}
    /**
     * 设置车辆历史轨迹返回
     *
     * @param ret
     * @param returnType
     * @param responseObject
     */
    private ChannelTypeHandleResponseObject setCarHistoricalTrajectoryResponse(
            ChannelTypeHandleResponseObject ret,
            String returnType, CarHistoricalTrajectoryResponseObject responseObject) {
        if (responseObject != null
                && "0000".equals(responseObject.getCode())) {
            CarHistoricalTrajectoryResponseObject.CarHistoricalTrajectoryResponseInfos responseInfos = responseObject.getData().getInfos().get(0);
            List<CarHistoricalTrajectoryResponseDetails> responseDetails = responseInfos.getTrackDetails();
            // 查询成功，返回结果
            ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
            ret.setResultBody(JSONArray.toJSONString(responseDetails));
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
            } else {
                ret.setResultCode(Constant.MATCH_CODE);
            }
        } else if (responseObject != null
                && "0001".equals(responseObject.getCode())) {
            // 查询成功，没有记录
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
            } else {
                ret.setResultCode(Constant.UN_FIND_NUM_CODE);
            }
            ret.setResultBody(Constant.RETURN_MESSAGE_60);
            ret.setResultDesc(Constant.RETURN_MESSAGE_60);
        } else {
            // 查询错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
            } else {
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
            }
            ret.setResultBody(Constant.OTHER_ERROR);
            ret.setResultDesc(Constant.OTHER_ERROR);
        }

        return ret;
    }

    public void chargeHandle(HttpServletRequest request, ChannelTypeHandleResponseObject ret,
                             CarHistoricalTrajectoryRequestObject requestObject) throws ParseException {

        int monthCount = SjjhConstants.MONTH_CHARGE_LIMIT;
        String userId = request.getHeader(SjjhConstants.USERID_HEADER_KEY);
        String channelId = request.getHeader(SjjhConstants.CHANNELID_HEADER_KEY);
        SimpleDateFormat monthSdf = new SimpleDateFormat("yyyyMM");
        Date current = new Date();
        String monthTime = monthSdf.format(current.getTime());

        Date startTime = DateUtils.parseDate(requestObject.getStartTime(), SjjhConstants.TIME_FORMAT);
        Date endTime = DateUtils.parseDate(requestObject.getEndTime(), SjjhConstants.TIME_FORMAT);
        List<String> dateList = getDays(startTime, endTime);

        int chargeCount = 0;
        for (String dateString : dateList) {
            Date date = DateUtils.parseDate(dateString, SjjhConstants.DATE_FORMAT);
            String queryMonth = monthSdf.format(date);

            String redisDateKey = userId + "_" + channelId + "_" + requestObject.getPlateNum() + "_" + monthTime + "_" + dateString;
            if (!stringRedisTemplate.boundValueOps(redisDateKey).setIfAbsent("1")) {
                continue;
            } else {
                stringRedisTemplate.boundValueOps(redisDateKey).expire(31, TimeUnit.DAYS);
                long redisMonthCount = stringRedisTemplate.boundHashOps(SjjhConstants.MONTH_CHARGE_COUNT)
                        .increment(userId + "_" + channelId + "_" + requestObject.getPlateNum() + "_" + monthTime + "_" + queryMonth, 1);
                if (redisMonthCount == 1) {
                    Calendar cal = Calendar.getInstance();
                    cal.setTime(current);
                    int lastDay = cal.getActualMaximum(Calendar.DAY_OF_MONTH);
                    cal.set(Calendar.DAY_OF_MONTH, lastDay);
                    cal.set(Calendar.HOUR_OF_DAY, 23);
                    cal.set(Calendar.MINUTE, 59);
                    cal.set(Calendar.SECOND, 59);
                    stringRedisTemplate.boundHashOps(SjjhConstants.MONTH_CHARGE_COUNT).expireAt(cal.getTime());
                    chargeCount++;
                    continue;
                }
                if (redisMonthCount <= monthCount) {
                    chargeCount++;
                }
            }
        }
        log.info("supplier10000041.chargeHandle chargeCount --- {}", chargeCount);
        if (chargeCount == 0) {
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
        } else {
            ret.setFeeCount(chargeCount);
        }
    }

    private boolean validateRequestParams(ChannelTypeHandleResponseObject ret, String returnType,
                                          CarHistoricalTrajectoryRequestObject requestObject) {
        Pattern pattern = Pattern.compile(SjjhConstants.TIME_REGEX);
        if (!validateParamNullValue(requestObject)) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            }
            return false;
        } else if (StringUtils.isBlank(requestObject.getPlateNum())
                || StringUtils.isBlank(requestObject.getStartTime())
                || StringUtils.isBlank(requestObject.getEndTime())
                || !PatternTools.checkResult(Constant.PATTERN_CAR_NUMBER_REGEX, requestObject.getPlateNum())
                || !pattern.matcher(requestObject.getStartTime()).matches()
                || !pattern.matcher(requestObject.getEndTime()).matches()) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(SjjhConstants.PARA_CHECK_CAR_OR_TIME_NUMBER_FAIL_TEXT);
            ret.setResultBody(SjjhConstants.PARA_CHECK_CAR_OR_TIME_NUMBER_FAIL_TEXT);
            return false;
        } else {
            return true;
        }
    }

    private boolean validateParamNullValue(Object jsonResolveObject) {
        ValidatorFactory vf = Validation.buildDefaultValidatorFactory();
        Validator validator = vf.getValidator();
        Set<ConstraintViolation<Object>> set = validator.validate(jsonResolveObject);
        for (ConstraintViolation<Object> con : set) {
            if (StringUtils.isNotBlank(con.getMessage())) {
                return false;
            }
        }
        return true;
    }

    public static List<String> getDays(Date startDate, Date endDate) throws ParseException {
        List<String> dateList = new ArrayList<>();
        SimpleDateFormat dateFormat = new SimpleDateFormat(SjjhConstants.DATE_FORMAT);
        long startDateTime = dateFormat.parse(dateFormat.format(startDate)).getTime();
        long endDateTime = dateFormat.parse(dateFormat.format(endDate)).getTime();
        int days = (int) ((endDateTime - startDateTime) / (1000 * 3600 * 24));

        for (int i = 0; i <= days; i++) {
            Date newDate = new Date(startDateTime + 1000 * 3600 * 24 * i);
            dateList.add(dateFormat.format(newDate));
        }
        return dateList;
    }

    @Override
    public ChannelTypeHandleResponseObject carLastPositionQuery(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        if (outTime <= SjjhConstants.PARA_ZERO) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }
        log.info("supplier10000041.carLastPositionQuery---customBody={},outTime={}", customBody, outTime);

        try {
            CarLastPositionRequestObject requestObject = objectMapper.readValue(customBody,
                    CarLastPositionRequestObject.class);
            log.info("supplier10000041.carLastPositionQuery---requestObject={}", requestObject);
            // 参数校验
            if (!validateRequestParams(ret, returnType, requestObject)) {
                ret.setCode(Constant.SUCCESS);
                request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
                return ret;
            }

            //生成签名
            Map<String, String> map = new HashMap<>();
            map.put("vclN", requestObject.getPlateNum());
            map.put("timeNearby", "24");
            map.put("uid", uid);
            String sign = ApiDigestUtil.execute(map, key, DigestALGEnum.MD5, "UTF-8");
            log.info("生成sign签名:{}", sign);
            map.put("sign", sign);
            MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
            String jsonStr = objectMapper.writeValueAsString(map);
            log.info("carLastPositionQuery请求上游参数:{}", jsonStr);

            RequestBody requestBody = RequestBody.create(mediaType, jsonStr);
            Request okRequest = new Request.Builder().post(requestBody).url(lastPositionUrl).build();
            OkHttpClient client = okHttpClient.newBuilder()
                    .sslSocketFactory(RxUtil.createSSLSocketFactory(), new RxUtil.TrustAllManager())
                    .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                    .readTimeout(outTime, TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime, TimeUnit.MILLISECONDS)
                    .build();
            Response response = client.newCall(okRequest).execute();
            String responseContext = "";
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            log.info("carLastPositionQuery返回结果:{}", responseContext);
            CarLastPositionResponseObject responseObject = objectMapper.readValue(responseContext,
                    CarLastPositionResponseObject.class);
            response.close();
            if (responseObject != null) {
                upstreamCode = responseObject.getCode();
                ret.setCode(Constant.SUCCESS);
                setCarLastPositionResponse(ret, returnType, responseObject);
                if (ret.getIsCharge() == Constant.IS_CHARGE) {
                    chargeHandle(request, ret, requestObject);
                }
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            log.info("supplier10000041.carLastPositionQuery接口-SocketTimeoutException：{}", ste);
            ErrorUtils.captureException(ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch (Exception ioe) {
            log.info("supplier10000041.carLastPositionQuery接口-Exception：{}", ioe);
            ErrorUtils.captureException(ioe);
            ret.setCode(Constant.FAIL);
        }
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private boolean validateRequestParams(ChannelTypeHandleResponseObject ret, String returnType,
                                          CarLastPositionRequestObject requestObject) {
        if (!validateParamNullValue(requestObject)) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            }
            return false;
        } else if (StringUtils.isBlank(requestObject.getPlateNum())
                || !PatternTools.checkResult(Constant.PATTERN_CAR_NUMBER_REGEX, requestObject.getPlateNum())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(SjjhConstants.PARA_CHECK_CAR_NUMBER_FAIL_TEXT);
            ret.setResultBody(SjjhConstants.PARA_CHECK_CAR_NUMBER_FAIL_TEXT);
            return false;
        } else {
            return true;
        }
    }

    /**
     * 设置车辆实时位置返回
     *
     * @param ret
     * @param returnType
     * @param responseObject
     */
    private ChannelTypeHandleResponseObject setCarLastPositionResponse(
            ChannelTypeHandleResponseObject ret,
            String returnType, CarLastPositionResponseObject responseObject) {
        if (responseObject != null
                && "0000".equals(responseObject.getCode())) {
            // 查询成功，返回结果
            ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
            ret.setResultBody(JSON.toJSONString(responseObject.getData()));
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
            } else {
                ret.setResultCode(Constant.MATCH_CODE);
            }
        } else if (responseObject != null
                && "0001".equals(responseObject.getCode())) {
            // 查询成功，没有记录
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
            } else {
                ret.setResultCode(Constant.UN_FIND_NUM_CODE);
            }
            ret.setResultBody(Constant.RETURN_MESSAGE_60);
            ret.setResultDesc(Constant.RETURN_MESSAGE_60);
        } else {
            // 查询错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
            } else {
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
            }
            ret.setResultBody(Constant.OTHER_ERROR);
            ret.setResultDesc(Constant.OTHER_ERROR);
        }
        return ret;
    }

    public void chargeHandle(HttpServletRequest request, ChannelTypeHandleResponseObject ret,
                             CarLastPositionRequestObject requestObject) {
        String monthLimit = request.getHeader(Constant.MONTH_CHARGE_LIMIT);
        log.info("monthLimit:{}", monthLimit);
        if ((monthLimit == null || "".equals(monthLimit))) {
            log.error("没有设置包月和包日标志位,month_limit:{}", monthLimit);
            return;
        }
        int monthCount = Integer.parseInt(monthLimit);
        String userId = request.getHeader(SjjhConstants.USERID_HEADER_KEY);
        String channelId = request.getHeader(SjjhConstants.CHANNELID_HEADER_KEY);
        SimpleDateFormat monthSdf = new SimpleDateFormat("yyyyMM");
        SimpleDateFormat daySdf = new SimpleDateFormat("yyyyMMdd");
        Date current = new Date();
        String monthTime = monthSdf.format(current.getTime());
        String dayTime = daySdf.format(current.getTime());

        String redisDateKey = userId + "_" + channelId + "_" + requestObject.getPlateNum() + "_" + monthTime + "_" + dayTime;
        if (!stringRedisTemplate.boundValueOps(redisDateKey).setIfAbsent("1")) {
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            return;
        } else {
            stringRedisTemplate.boundValueOps(redisDateKey).expire(31, TimeUnit.DAYS);
            long redisMonthCount = 0;
            if (monthCount != -1) {
                redisMonthCount = stringRedisTemplate.boundHashOps(SjjhConstants.MONTH_CHARGE_COUNT)
                        .increment(userId + "_" + channelId + "_" + requestObject.getPlateNum() + "_" + monthTime, 1);
                if (redisMonthCount == 1) {
                    Calendar cal = Calendar.getInstance();
                    cal.setTime(current);
                    int lastDay = cal.getActualMaximum(Calendar.DAY_OF_MONTH);
                    cal.set(Calendar.DAY_OF_MONTH, lastDay);
                    cal.set(Calendar.HOUR_OF_DAY, 23);
                    cal.set(Calendar.MINUTE, 59);
                    cal.set(Calendar.SECOND, 59);
                    stringRedisTemplate.boundHashOps(SjjhConstants.MONTH_CHARGE_COUNT).expireAt(cal.getTime());
                }
            }
            if (monthCount != -1 && redisMonthCount > monthCount) {
                ret.setIsCharge(Constant.IS_NOT_CHARGE);
                return;
            }
        }
    }

    @Override
    public ChannelTypeHandleResponseObject truckExistCheck(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        if (outTime <= SjjhConstants.PARA_ZERO) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }
        log.info("supplier10000041.truckExistCheck---customBody={},outTime={}", customBody, outTime);
        try {
            TruckExistCheckRequestObject requestObject = objectMapper.readValue(customBody,
                    TruckExistCheckRequestObject.class);
            log.info("supplier10000041.truckExistCheck---requestObject={}", requestObject);
            // 参数校验
            if (!validateRequestParams(ret, returnType, requestObject)) {
                ret.setCode(Constant.SUCCESS);
                request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
                return ret;
            }

            //生成签名
            Map<String, String> map = new HashMap<>();
            map.put("vclN", requestObject.getPlateNum());
            map.put("uid", uid);
            String sign = ApiDigestUtil.execute(map, key, DigestALGEnum.MD5, "UTF-8");
            log.info("生成sign签名:{}", sign);
            map.put("sign", sign);
            MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
            String jsonStr = objectMapper.writeValueAsString(map);
            log.info("truckExistCheck请求上游参数:{}", jsonStr);

            RequestBody requestBody = RequestBody.create(mediaType, jsonStr);
            Request okRequest = new Request.Builder().post(requestBody).url(truckExistCheck).build();
            OkHttpClient client = okHttpClient.newBuilder()
                    .sslSocketFactory(RxUtil.createSSLSocketFactory(), new RxUtil.TrustAllManager())
                    .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                    .readTimeout(outTime, TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime, TimeUnit.MILLISECONDS)
                    .build();
            Response response = client.newCall(okRequest).execute();
            String responseContext = "";
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            log.info("truckExistCheck返回结果:{}", responseContext);
            TruckExistCheckResponseObject responseObject = objectMapper.readValue(responseContext,
                    TruckExistCheckResponseObject.class);
            response.close();
            if (responseObject != null) {
                upstreamCode = responseObject.getCode();
                ret.setCode(Constant.SUCCESS);
                setTruckExistCheckResponse(ret, returnType, responseObject);
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            log.info("supplier10000041.truckExistCheck接口-SocketTimeoutException：{}", ste);
            ErrorUtils.captureException(ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch (Exception ioe) {
            log.info("supplier10000041.truckExistCheck接口-Exception：{}", ioe);
            ErrorUtils.captureException(ioe);
            ret.setCode(Constant.FAIL);
        }
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private boolean validateRequestParams(ChannelTypeHandleResponseObject ret, String returnType,
                                          TruckExistCheckRequestObject requestObject) {
        if (!validateParamNullValue(requestObject)) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            }
            return false;
        } else if (StringUtils.isBlank(requestObject.getPlateNum())
                || !PatternTools.checkResult(Constant.PATTERN_CAR_NUMBER_REGEX, requestObject.getPlateNum())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(SjjhConstants.PARA_CHECK_CAR_OR_TIME_NUMBER_FAIL_TEXT);
            ret.setResultBody(SjjhConstants.PARA_CHECK_CAR_OR_TIME_NUMBER_FAIL_TEXT);
            return false;
        } else {
            return true;
        }
    }

    private void setTruckExistCheckResponse(ChannelTypeHandleResponseObject ret,
                                            String returnType, TruckExistCheckResponseObject responseObject) {
        boolean isCharge = responseObject != null
                && ("0000".equals(responseObject.getCode()) || "0001".equals(responseObject.getCode()));
        if (isCharge) {
            ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
        }
        if (responseObject != null
                && "0000".equals(responseObject.getCode())) {
            // 查询成功，返回结果
            String result = responseObject.getData().getResult();
            if (result.equals("yes")) {
                ret.setResultBody(SjjhConstants.TRUCK_EXIST_ON_LINE);
                ret.setResultDesc(SjjhConstants.TRUCK_EXIST_ON_LINE);
            } else {
                ret.setResultBody(SjjhConstants.TRUCK_NOT_EXIST_ON_LINE);
                ret.setResultDesc(SjjhConstants.TRUCK_NOT_EXIST_ON_LINE);
            }
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
            } else {
                ret.setResultCode(Constant.MATCH_CODE);
            }
        } else if (responseObject != null
                && "0001".equals(responseObject.getCode())) {
            // 查询成功，查无结果
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
            } else {
                ret.setResultCode(Constant.UN_FIND_NUM_CODE);
            }
            ret.setResultBody(SjjhConstants.NO_RESULT);
            ret.setResultDesc(SjjhConstants.NO_RESULT);
        } else if (responseObject != null
                && ("0002".equals(responseObject.getCode()) || "1000".equals(responseObject.getCode()))) {
            // 参数错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            } else {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
        } else {
            // 查询错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
            } else {
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
            }
            ret.setResultBody(Constant.OTHER_ERROR);
            ret.setResultDesc(Constant.OTHER_ERROR);
        }
    }

    @Override
    public ChannelTypeHandleResponseObject carsLastPositionQuery(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        if (outTime <= SjjhConstants.PARA_ZERO) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }
        log.info("supplier10000041.carsLastPositionQuery---customBody={},outTime={}", customBody, outTime);
        try {
            CarsLastPositionRequestObject requestObject = objectMapper.readValue(customBody,
                    CarsLastPositionRequestObject.class);
            log.info("supplier10000041.carsLastPositionQuery---requestObject={}", requestObject);
            // 参数校验
            if (!validateRequestParams(ret, returnType, requestObject)) {
                ret.setCode(Constant.SUCCESS);
                request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
                return ret;
            }
            StringBuilder vehicleParam = new StringBuilder();
            for (String plateNum : requestObject.getPlateNums()) {
                vehicleParam.
                        append(plateNum)
                        .append("_2")
                        .append(",");
            }
            //生成签名
            Map<String, String> map = new HashMap<>();
            map.put("vclNs", vehicleParam.toString());
            map.put("timeNearby", "24");
            map.put("uid", uid);
            String sign = ApiDigestUtil.execute(map, key, DigestALGEnum.MD5, "UTF-8");
            log.info("生成sign签名:{}", sign);
            map.put("sign", sign);
            MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
            String jsonStr = objectMapper.writeValueAsString(map);
            log.info("carsLastPositionQuery请求上游参数:{}", jsonStr);

            RequestBody requestBody = RequestBody.create(mediaType, jsonStr);
            Request okRequest = new Request.Builder().post(requestBody).url(carsLastPositionUrl).build();
            OkHttpClient client = okHttpClient.newBuilder()
                    .sslSocketFactory(RxUtil.createSSLSocketFactory(), new RxUtil.TrustAllManager())
                    .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                    .readTimeout(outTime, TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime, TimeUnit.MILLISECONDS)
                    .build();
            Response response = client.newCall(okRequest).execute();
            String responseContext = "";
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            log.info("carsLastPositionQuery返回结果:{}", responseContext);
            CarsLastPositionResponseObject responseObject = objectMapper.readValue(responseContext,
                    CarsLastPositionResponseObject.class);
            response.close();
            if (responseObject != null) {
                upstreamCode = responseObject.getCode();
                ret.setCode(Constant.SUCCESS);
                setCarsLastPositionResponse(ret, returnType, responseObject);
                chargeHandle(request, ret, responseObject);
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            log.info("supplier10000041.carsLastPositionQuery接口-SocketTimeoutException：{}", ste);
            ErrorUtils.captureException(ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch (Exception ioe) {
            log.info("supplier10000041.carsLastPositionQuery接口-Exception：{}", ioe);
            ErrorUtils.captureException(ioe);
            ret.setCode(Constant.FAIL);
        }
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private boolean validateRequestParams(ChannelTypeHandleResponseObject ret, String returnType,
                                          CarsLastPositionRequestObject requestObject) {
        if (!validateParamNullValue(requestObject)) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            }
            return false;
        }
        StringBuilder errorPlateNum = new StringBuilder();
        for (String plateNum : requestObject.getPlateNums()) {
            if (StringUtils.isBlank(plateNum)
                    || !PatternTools.checkResult(Constant.PATTERN_CAR_NUMBER_REGEX, plateNum)) {
                errorPlateNum.append(plateNum).append(",");
            }
        }
        if (errorPlateNum.length() != 0) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc("车牌号格式错误，错误车牌号为：" + errorPlateNum.toString());
            ret.setResultBody("车牌号格式错误，错误车牌号为：" + errorPlateNum.toString());
            return false;
        }
        return true;
    }

    private void setCarsLastPositionResponse(ChannelTypeHandleResponseObject ret,
                                             String returnType, CarsLastPositionResponseObject responseObject) {
        if (responseObject != null
                && "0000".equals(responseObject.getCode())) {
            // 查询成功，返回结果
            ret.setResultBody(JSON.toJSONString(responseObject.getData().getInfos()));
            ret.setResultDesc(Constant.QUERY_SUCCESS);
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
            } else {
                ret.setResultCode(Constant.MATCH_CODE);
            }
        } else if (responseObject != null
                && "0001".equals(responseObject.getCode())) {
            // 查询成功，没有记录
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
            } else {
                ret.setResultCode(Constant.UN_FIND_NUM_CODE);
            }
            ret.setResultBody(SjjhConstants.NO_RESULT);
            ret.setResultDesc(SjjhConstants.NO_RESULT);
        } else if (responseObject != null
                && ("0002".equals(responseObject.getCode()) || "1000".equals(responseObject.getCode()))) {
            // 参数错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            } else {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
        } else {
            // 查询错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
            } else {
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
            }
            ret.setResultBody(Constant.OTHER_ERROR);
            ret.setResultDesc(Constant.OTHER_ERROR);
        }
    }

    public void chargeHandle(HttpServletRequest request, ChannelTypeHandleResponseObject ret,
                             CarsLastPositionResponseObject responseObject) throws ParseException {
        List<String> plateNums = new ArrayList<>();
        if (responseObject.getCode().equals("0000")) {
            List<CarsLastPositionResponseObject.CarsLastPositionResponseInfo> infos = responseObject.getData().getInfos();
            for (CarsLastPositionResponseObject.CarsLastPositionResponseInfo info : infos) {
                if (info.getCode().equals("0000")) {
                    plateNums.add(info.getVno());
                }
            }
        }

        int monthCount = 20;
        String userId = request.getHeader(SjjhConstants.USERID_HEADER_KEY);
        String channelId = request.getHeader(SjjhConstants.CHANNELID_HEADER_KEY);
        SimpleDateFormat monthSdf = new SimpleDateFormat("yyyyMM");
        SimpleDateFormat dateSdf = new SimpleDateFormat("yyyyMMdd");
        Date current = new Date();
        String monthTime = monthSdf.format(current.getTime());
        String dateTime = dateSdf.format(current.getTime());

        int chargeCount = 0;
        for (String plateNum : plateNums) {
            String redisDateKey = userId + "_" + channelId + "_" + plateNum + "_" + monthTime + "_" + dateTime;
            if (!stringRedisTemplate.boundValueOps(redisDateKey).setIfAbsent("1")) {
                continue;
            } else {
                stringRedisTemplate.boundValueOps(redisDateKey).expire(1, TimeUnit.DAYS);
                long redisMonthCount = stringRedisTemplate.boundHashOps(SjjhConstants.MONTH_CHARGE_COUNT)
                        .increment(userId + "_" + channelId + "_" + plateNum + "_" + monthTime, 1);
                if (redisMonthCount == 1) {
                    Calendar cal = Calendar.getInstance();
                    cal.setTime(current);
                    int lastDay = cal.getActualMaximum(Calendar.DAY_OF_MONTH);
                    cal.set(Calendar.DAY_OF_MONTH, lastDay);
                    cal.set(Calendar.HOUR_OF_DAY, 23);
                    cal.set(Calendar.MINUTE, 59);
                    cal.set(Calendar.SECOND, 59);
                    stringRedisTemplate.boundHashOps(SjjhConstants.MONTH_CHARGE_COUNT).expireAt(cal.getTime());
                    chargeCount++;
                    continue;
                }
                if (redisMonthCount <= monthCount) {
                    chargeCount++;
                }
            }
        }
        log.info("supplier10000041.chargeHandle chargeCount --- {}", chargeCount);
        if (chargeCount == 0) {
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
        } else {
            ret.setFeeCount(chargeCount);
            ret.setIsCharge(Constant.IS_CHARGE);
        }
    }

    @Override
    public ChannelTypeHandleResponseObject enterpriseTransportPermitQuery(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        if (outTime <= SjjhConstants.PARA_ZERO) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }
        log.info("supplier10000041.enterpriseTransportPermitQuery---customBody={},outTime={}", customBody, outTime);
        try {
            EnterpriseTransportPermitRequestObject requestObject = objectMapper.readValue(customBody,
                    EnterpriseTransportPermitRequestObject.class);
            log.info("supplier10000041.enterpriseTransportPermitQuery---requestObject={}", requestObject);
            // 参数校验
            if (!validateRequestParams(ret, returnType, requestObject)) {
                ret.setCode(Constant.SUCCESS);
                request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
                return ret;
            }

            //生成签名
            Map<String, String> map = new HashMap<>();
            map.put("enterpriseName", requestObject.getEnterpriseName());
            map.put("uid", uid);
            String sign = ApiDigestUtil.execute(map, key, DigestALGEnum.MD5, "UTF-8");
            log.info("生成sign签名:{}", sign);
            map.put("sign", sign);
            MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
            String jsonStr = objectMapper.writeValueAsString(map);
            log.info("enterpriseTransportPermitQuery请求上游参数:{}", jsonStr);

            RequestBody requestBody = RequestBody.create(mediaType, jsonStr);
            Request okRequest = new Request.Builder().post(requestBody).url(enterpriseQuery).build();
            OkHttpClient client = okHttpClient.newBuilder()
                    .sslSocketFactory(RxUtil.createSSLSocketFactory(), new RxUtil.TrustAllManager())
                    .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                    .readTimeout(outTime, TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime, TimeUnit.MILLISECONDS)
                    .build();
            Response response = client.newCall(okRequest).execute();
            String responseContext = "";
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            log.info("enterpriseTransportPermitQuery返回结果:{}", responseContext);
            EnterpriseTransportPermitResponseObject responseObject = objectMapper.readValue(responseContext,
                    EnterpriseTransportPermitResponseObject.class);
            response.close();
            if (responseObject != null) {
                upstreamCode = responseObject.getCode();
                ret.setCode(Constant.SUCCESS);
                setEnterpriseTransportPermitResponse(ret, returnType, responseObject);
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            log.info("supplier10000041.enterpriseTransportPermitQuery接口-SocketTimeoutException：{}", ste);
            ErrorUtils.captureException(ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch (Exception ioe) {
            log.info("supplier10000041.enterpriseTransportPermitQuery接口-Exception：{}", ioe);
            ErrorUtils.captureException(ioe);
            ret.setCode(Constant.FAIL);
        }
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private boolean validateRequestParams(ChannelTypeHandleResponseObject ret, String returnType,
                                          EnterpriseTransportPermitRequestObject requestObject) {
        if (!validateParamNullValue(requestObject)) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            }
            return false;
        } else if (StringUtils.isBlank(requestObject.getEnterpriseName())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            return false;
        } else {
            return true;
        }
    }

    private void setEnterpriseTransportPermitResponse(ChannelTypeHandleResponseObject ret, String returnType,
                                                      EnterpriseTransportPermitResponseObject responseObject) {
        boolean isCharge = responseObject != null
                && ("0000".equals(responseObject.getCode()) || "0001".equals(responseObject.getCode()));
        if (isCharge) {
            ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
        }
        if (responseObject != null
                && "0000".equals(responseObject.getCode())) {
            // 查询成功，返回结果
            ret.setResultBody(JSON.toJSONString(responseObject.getData()));
            ret.setResultDesc(Constant.QUERY_SUCCESS);
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
            } else {
                ret.setResultCode(Constant.MATCH_CODE);
            }
        } else if (responseObject != null
                && "0001".equals(responseObject.getCode())) {
            // 查询成功，查无结果
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
            } else {
                ret.setResultCode(Constant.UN_FIND_NUM_CODE);
            }
            ret.setResultBody(SjjhConstants.NO_RESULT);
            ret.setResultDesc(SjjhConstants.NO_RESULT);
        } else if (responseObject != null
                && ("0002".equals(responseObject.getCode()) || "1000".equals(responseObject.getCode()))) {
            // 参数错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            } else {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
        } else {
            // 查询错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
            } else {
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
            }
            ret.setResultBody(Constant.OTHER_ERROR);
            ret.setResultDesc(Constant.OTHER_ERROR);
        }
    }

    @Override
    public ChannelTypeHandleResponseObject personQualificationCertificateQuery(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        if (outTime <= SjjhConstants.PARA_ZERO) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }
        log.info("supplier10000041.personQualificationCertificateQuery---customBody={},outTime={}", customBody, outTime);
        try {
            PersonQualificationCertificateRequestObject requestObject = objectMapper.readValue(customBody,
                    PersonQualificationCertificateRequestObject.class);
            log.info("supplier10000041.personQualificationCertificateQuery---requestObject={}", requestObject);
            // 参数校验
            if (!validateRequestParams(ret, returnType, requestObject)) {
                ret.setCode(Constant.SUCCESS);
                request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
                return ret;
            }

            //生成签名
            Map<String, String> map = new HashMap<>();
            map.put("nameOfPerson", requestObject.getName());
            if (StringUtils.isNotBlank(requestObject.getIdCode())) {
                map.put("identityDocumentNumber", requestObject.getIdCode());
            }
            if (StringUtils.isNotBlank(requestObject.getQualificationCertificateNumber())) {
                map.put("qualificationCertificateNumber", requestObject.getQualificationCertificateNumber());
            }
            map.put("provinceCode", requestObject.getProvinceCode());
            map.put("uid", uid);
            String sign = ApiDigestUtil.execute(map, key, DigestALGEnum.MD5, "UTF-8");
            log.info("生成sign签名:{}", sign);
            map.put("sign", sign);
            MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
            String jsonStr = objectMapper.writeValueAsString(map);
            log.info("personQualificationCertificateQuery请求上游参数:{}", jsonStr);

            RequestBody requestBody = RequestBody.create(mediaType, jsonStr);
            Request okRequest = new Request.Builder().post(requestBody).url(personQuery).build();
            OkHttpClient client = okHttpClient.newBuilder()
                    .sslSocketFactory(RxUtil.createSSLSocketFactory(), new RxUtil.TrustAllManager())
                    .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                    .readTimeout(outTime, TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime, TimeUnit.MILLISECONDS)
                    .build();
            Response response = client.newCall(okRequest).execute();
            String responseContext = "";
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            log.info("personQualificationCertificateQuery返回结果:{}", responseContext);
            PersonQualificationCertificateResponseObject responseObject = objectMapper.readValue(responseContext,
                    PersonQualificationCertificateResponseObject.class);
            response.close();
            if (responseObject != null) {
                upstreamCode = responseObject.getCode();
                ret.setCode(Constant.SUCCESS);
                setPersonQualificationCertificateResponse(ret, returnType, responseObject);
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            log.info("supplier10000041.personQualificationCertificateQuery接口-SocketTimeoutException：{}", ste);
            ErrorUtils.captureException(ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch (Exception ioe) {
            log.info("supplier10000041.personQualificationCertificateQuery接口-Exception：{}", ioe);
            ErrorUtils.captureException(ioe);
            ret.setCode(Constant.FAIL);
        }
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private boolean validateRequestParams(ChannelTypeHandleResponseObject ret, String returnType,
                                          PersonQualificationCertificateRequestObject requestObject) {
        if (!validateParamNullValue(requestObject)) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            }
            return false;
        } else if (StringUtils.isBlank(requestObject.getName()) ||
                !PatternTools.checkResult(Constant.PATTERN_CN_NAME_REGEX, requestObject.getName())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.NAME_FORMAT_ERROR_CODE);
                ret.setResultDesc(Constant.NAME_FORMAT_ERROR);
                ret.setResultBody(Constant.NAME_FORMAT_ERROR);
            } else {
                ret.setResultCode(Constant.JK_NAME_FORMAT_ERROR_CODE);
                ret.setResultDesc(Constant.JK_NAME_FORMAT_ERROR);
                ret.setResultBody(Constant.JK_NAME_FORMAT_ERROR);
            }
            return false;
        } else if (StringUtils.isNotBlank(requestObject.getIdCode())
                && !PatternTools.checkResult(Constant.PATTERN_ID_NUMBER_REGEX, requestObject.getIdCode())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.IDCODE_FORMAT_ERROR_CODE);
                ret.setResultDesc(Constant.IDCODE_FORMAT_ERROR);
                ret.setResultBody(Constant.IDCODE_FORMAT_ERROR);
            } else {
                ret.setResultCode(Constant.JK_IDCODE_FORMAT_ERROR_CODE);
                ret.setResultDesc(Constant.JK_IDCODE_FORMAT_ERROR);
                ret.setResultBody(Constant.JK_IDCODE_FORMAT_ERROR);
            }
            return false;
        } else if (StringUtils.isBlank(requestObject.getProvinceCode())
                || requestObject.getProvinceCode().length() > 6) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultDesc(SjjhConstants.ERROR_PROVINCE_CODE);
                ret.setResultBody(SjjhConstants.ERROR_PROVINCE_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultDesc(SjjhConstants.ERROR_PROVINCE_CODE);
                ret.setResultBody(SjjhConstants.ERROR_PROVINCE_CODE);
            }
            return false;
        } else if (StringUtils.isBlank(requestObject.getIdCode())
                && StringUtils.isBlank(requestObject.getQualificationCertificateNumber())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultDesc(SjjhConstants.ERROR_PERSON_QUERY_PARAM);
                ret.setResultBody(SjjhConstants.ERROR_PERSON_QUERY_PARAM);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultDesc(SjjhConstants.ERROR_PERSON_QUERY_PARAM);
                ret.setResultBody(SjjhConstants.ERROR_PERSON_QUERY_PARAM);
            }
            return false;
        } else {
            return true;
        }
    }

    private void setPersonQualificationCertificateResponse(ChannelTypeHandleResponseObject ret, String returnType,
                                                           PersonQualificationCertificateResponseObject responseObject) {
        boolean isCharge = responseObject != null
                && ("0000".equals(responseObject.getCode()) || "0001".equals(responseObject.getCode()));
        if (isCharge) {
            ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
        }
        if (responseObject != null
                && "0000".equals(responseObject.getCode())) {
            // 查询成功，返回结果
            ret.setResultBody(JSON.toJSONString(responseObject.getData()));
            ret.setResultDesc(Constant.QUERY_SUCCESS);
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
            } else {
                ret.setResultCode(Constant.MATCH_CODE);
            }
        } else if (responseObject != null
                && "0001".equals(responseObject.getCode())) {
            // 查询成功，查无结果
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
            } else {
                ret.setResultCode(Constant.UN_FIND_NUM_CODE);
            }
            ret.setResultBody(SjjhConstants.NO_RESULT);
            ret.setResultDesc(SjjhConstants.NO_RESULT);
        } else if (responseObject != null
                && ("0002".equals(responseObject.getCode()) || "1000".equals(responseObject.getCode()))) {
            // 参数错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            } else {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
        } else {
            // 查询错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
            } else {
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
            }
            ret.setResultBody(Constant.OTHER_ERROR);
            ret.setResultDesc(Constant.OTHER_ERROR);
        }
    }

    @Override
    public ChannelTypeHandleResponseObject vehicleTransportPermitQuery(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        if (outTime <= SjjhConstants.PARA_ZERO) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }
        log.info("supplier10000041.vehicleTransportPermitQuery---customBody={},outTime={}", customBody, outTime);
        try {
            VehicleTransportPermitRequestObject requestObject = objectMapper.readValue(customBody,
                    VehicleTransportPermitRequestObject.class);
            log.info("supplier10000041.vehicleTransportPermitQuery---requestObject={}", requestObject);
            // 参数校验
            if (!validateRequestParams(ret, returnType, requestObject)) {
                ret.setCode(Constant.SUCCESS);
                request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
                return ret;
            }

            //生成签名
            Map<String, String> map = new HashMap<>();
            map.put("vehicleNumber", requestObject.getVehicleNumber());
            if (StringUtils.isNotBlank(requestObject.getLicensePlateTypeCode())) {
                map.put("licensePlateTypeCode", requestObject.getLicensePlateTypeCode());
            }
            map.put("uid", uid);
            String sign = ApiDigestUtil.execute(map, key, DigestALGEnum.MD5, "UTF-8");
            log.info("生成sign签名:{}", sign);
            map.put("sign", sign);
            MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
            String jsonStr = objectMapper.writeValueAsString(map);
            log.info("vehicleTransportPermitQuery请求上游参数:{}", jsonStr);

            RequestBody requestBody = RequestBody.create(mediaType, jsonStr);
            Request okRequest = new Request.Builder().post(requestBody).url(vehicleQuery).build();
            OkHttpClient client = okHttpClient.newBuilder()
                    .sslSocketFactory(RxUtil.createSSLSocketFactory(), new RxUtil.TrustAllManager())
                    .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                    .readTimeout(outTime, TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime, TimeUnit.MILLISECONDS)
                    .build();
            Response response = client.newCall(okRequest).execute();
            String responseContext = "";
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            log.info("vehicleTransportPermitQuery返回结果:{}", responseContext);
            VehicleTransportPermitResponseObject responseObject = objectMapper.readValue(responseContext,
                    VehicleTransportPermitResponseObject.class);
            response.close();
            if (responseObject != null) {
                upstreamCode = responseObject.getCode();
                ret.setCode(Constant.SUCCESS);
                setVehicleTransportPermitResponse(ret, returnType, responseObject);
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            log.info("supplier10000041.vehicleTransportPermitQuery接口-SocketTimeoutException：{}", ste);
            ErrorUtils.captureException(ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch (Exception ioe) {
            log.info("supplier10000041.vehicleTransportPermitQuery接口-Exception：{}", ioe);
            ErrorUtils.captureException(ioe);
            ret.setCode(Constant.FAIL);
        }
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private boolean validateRequestParams(ChannelTypeHandleResponseObject ret, String returnType,
                                          VehicleTransportPermitRequestObject requestObject) {
        if (!validateParamNullValue(requestObject)) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            }
            return false;
        } else if (StringUtils.isBlank(requestObject.getVehicleNumber())
                || !PatternTools.checkResult(Constant.PATTERN_CAR_NUMBER_REGEX, requestObject.getVehicleNumber())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(SjjhConstants.PARA_CHECK_CAR_NUMBER_FAIL_TEXT);
            ret.setResultBody(SjjhConstants.PARA_CHECK_CAR_NUMBER_FAIL_TEXT);
            return false;
        } else if (StringUtils.isNotBlank(requestObject.getLicensePlateTypeCode())
                && !requestObject.getLicensePlateTypeCode().equals("1") && !requestObject.getLicensePlateTypeCode().equals("2")) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(SjjhConstants.ERROR_PLATE_COLOR);
            ret.setResultBody(SjjhConstants.ERROR_PLATE_COLOR);
            return false;
        } else {
            return true;
        }
    }

    private void setVehicleTransportPermitResponse(ChannelTypeHandleResponseObject ret, String returnType,
                                                   VehicleTransportPermitResponseObject responseObject) {
        boolean isCharge = responseObject != null
                && ("0000".equals(responseObject.getCode()) || "0001".equals(responseObject.getCode()));
        if (isCharge) {
            ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
        }
        if (responseObject != null
                && "0000".equals(responseObject.getCode())) {
            // 查询成功，返回结果
            ret.setResultBody(JSON.toJSONString(responseObject.getData()));
            ret.setResultDesc(Constant.QUERY_SUCCESS);
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
            } else {
                ret.setResultCode(Constant.MATCH_CODE);
            }
        } else if (responseObject != null
                && "0001".equals(responseObject.getCode())) {
            // 查询成功，查无结果
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
            } else {
                ret.setResultCode(Constant.UN_FIND_NUM_CODE);
            }
            ret.setResultBody(SjjhConstants.NO_RESULT);
            ret.setResultDesc(SjjhConstants.NO_RESULT);
        } else if (responseObject != null
                && ("0002".equals(responseObject.getCode()) || "1000".equals(responseObject.getCode()))) {
            // 参数错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            } else {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
        } else {
            // 查询错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
            } else {
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
            }
            ret.setResultBody(Constant.OTHER_ERROR);
            ret.setResultDesc(Constant.OTHER_ERROR);
        }
    }

    @Override
    public ChannelTypeHandleResponseObject carOwnerAuthenticityCheck(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        if (outTime <= SjjhConstants.PARA_ZERO) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }
        log.info("supplier10000041.carOwnerAuthenticityCheck---customBody={},outTime={}", customBody, outTime);
        try {
            CarOwnerAuthenticityCheckRequestObject requestObject = objectMapper.readValue(customBody,
                    CarOwnerAuthenticityCheckRequestObject.class);
            log.info("supplier10000041.carOwnerAuthenticityCheck---requestObject={}", requestObject);
            // 参数校验
            if (!validateRequestParams(ret, returnType, requestObject)) {
                ret.setCode(Constant.SUCCESS);
                request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
                return ret;
            }

            //生成签名
            Map<String, String> map = new HashMap<>();
            map.put("vclN", requestObject.getPlateNum());
            map.put("ownerName", requestObject.getName());
            if (StringUtils.isNotBlank(requestObject.getMobile())) {
                map.put("ownerPhone", requestObject.getMobile());
            }
            map.put("uid", uid);
            String sign = ApiDigestUtil.execute(map, key, DigestALGEnum.MD5, "UTF-8");
            log.info("生成sign签名:{}", sign);
            map.put("sign", sign);
            MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
            String jsonStr = objectMapper.writeValueAsString(map);
            log.info("carOwnerAuthenticityCheck请求上游参数:{}", jsonStr);

            RequestBody requestBody = RequestBody.create(mediaType, jsonStr);
            Request okRequest = new Request.Builder().post(requestBody).url(carOwnerRealness).build();
            OkHttpClient client = okHttpClient.newBuilder()
                    .sslSocketFactory(RxUtil.createSSLSocketFactory(), new RxUtil.TrustAllManager())
                    .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                    .readTimeout(outTime, TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime, TimeUnit.MILLISECONDS)
                    .build();
            Response response = client.newCall(okRequest).execute();
            String responseContext = "";
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            log.info("carOwnerAuthenticityCheck返回结果:{}", responseContext);
            CarOwnerAuthenticityCheckResponseObject responseObject = objectMapper.readValue(responseContext,
                    CarOwnerAuthenticityCheckResponseObject.class);
            response.close();
            if (responseObject != null) {
                upstreamCode = responseObject.getCode();
                ret.setCode(Constant.SUCCESS);
                setCarOwnerAuthenticityResponse(ret, returnType, responseObject);
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            log.info("supplier10000041.carOwnerAuthenticityCheck接口-SocketTimeoutException：{}", ste);
            ErrorUtils.captureException(ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch (Exception ioe) {
            log.info("supplier10000041.carOwnerAuthenticityCheck接口-Exception：{}", ioe);
            ErrorUtils.captureException(ioe);
            ret.setCode(Constant.FAIL);
        }
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private boolean validateRequestParams(ChannelTypeHandleResponseObject ret, String returnType,
                                          CarOwnerAuthenticityCheckRequestObject requestObject) {
        if (!validateParamNullValue(requestObject)) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            }
            return false;
        } else if (StringUtils.isBlank(requestObject.getPlateNum())
                || !PatternTools.checkResult(Constant.PATTERN_CAR_NUMBER_REGEX, requestObject.getPlateNum())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(SjjhConstants.PARA_CHECK_CAR_NUMBER_FAIL_TEXT);
            ret.setResultBody(SjjhConstants.PARA_CHECK_CAR_NUMBER_FAIL_TEXT);
            return false;
        } else if (StringUtils.isBlank(requestObject.getName())
                || !PatternTools.checkResult(Constant.PATTERN_CN_NAME_REGEX, requestObject.getPlateNum())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.NAME_FORMAT_ERROR_CODE);
            } else {
                ret.setResultCode(Constant.JK_NAME_FORMAT_ERROR_CODE);
            }
            ret.setResultDesc(Constant.JK_NAME_FORMAT_ERROR);
            ret.setResultBody(Constant.JK_NAME_FORMAT_ERROR);
            return false;
        } else if (StringUtils.isNotBlank(requestObject.getMobile())
                && !PatternTools.checkResult(Constant.PATTERN_MOBILE_REGEX, requestObject.getMobile())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.MOBILE_FORMAT_ERROR_CODE);
            } else {
                ret.setResultCode(Constant.JK_MOBILE_FORMAT_ERROR_CODE);
            }
            ret.setResultDesc(Constant.JK_MOBILE_FORMAT_ERROR);
            ret.setResultBody(Constant.JK_MOBILE_FORMAT_ERROR);
            return false;
        } else {
            return true;
        }
    }

    private void setCarOwnerAuthenticityResponse(ChannelTypeHandleResponseObject ret, String returnType,
                                                 CarOwnerAuthenticityCheckResponseObject responseObject) {
        boolean isCharge = responseObject != null
                && ("0000".equals(responseObject.getCode()) || "0001".equals(responseObject.getCode()));
        if (isCharge) {
            ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
        }
        if (responseObject != null
                && "0000".equals(responseObject.getCode())) {
            if (responseObject.getData().getResult().equals("yes")) {
                ret.setResultBody(SjjhConstants.IS_CAR_OWNER);
                ret.setResultDesc(SjjhConstants.IS_CAR_OWNER);
            } else if (responseObject.getData().getResult().equals("name")) {
                ret.setResultBody(SjjhConstants.CAR_OWNER_AUTHENTICITY_NAME_ERROR);
                ret.setResultDesc(SjjhConstants.CAR_OWNER_AUTHENTICITY_NAME_ERROR);
            } else if (responseObject.getData().getResult().equals("phone")) {
                ret.setResultBody(SjjhConstants.CAR_OWNER_AUTHENTICITY_PHONE_ERROR);
                ret.setResultDesc(SjjhConstants.CAR_OWNER_AUTHENTICITY_PHONE_ERROR);
            } else {
                ret.setResultBody(SjjhConstants.CAR_OWNER_AUTHENTICITY_ERROR);
                ret.setResultDesc(SjjhConstants.CAR_OWNER_AUTHENTICITY_ERROR);
            }
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
            } else {
                ret.setResultCode(Constant.MATCH_CODE);
            }
        } else if (responseObject != null
                && "0001".equals(responseObject.getCode())) {
            // 查询成功，查无结果
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
            } else {
                ret.setResultCode(Constant.UN_FIND_NUM_CODE);
            }
            ret.setResultBody(SjjhConstants.NO_RESULT);
            ret.setResultDesc(SjjhConstants.NO_RESULT);
        } else if (responseObject != null
                && ("0002".equals(responseObject.getCode()) || "1000".equals(responseObject.getCode()))) {
            // 参数错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            } else {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
        } else {
            // 查询错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
            } else {
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
            }
            ret.setResultBody(Constant.OTHER_ERROR);
            ret.setResultDesc(Constant.OTHER_ERROR);
        }
    }

    @Override
    public ChannelTypeHandleResponseObject truckInfoQuery(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        if (outTime <= SjjhConstants.PARA_ZERO) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }
        log.info("supplier10000041.truckInfoQuery---customBody={},outTime={}", customBody, outTime);
        try {
            TruckInfoQueryRequestObject requestObject = objectMapper.readValue(customBody,
                    TruckInfoQueryRequestObject.class);
            log.info("supplier10000041.truckInfoQuery---requestObject={}", requestObject);
            // 参数校验
            if (!validateRequestParams(ret, returnType, requestObject)) {
                ret.setCode(Constant.SUCCESS);
                request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
                return ret;
            }

            //生成签名
            Map<String, String> map = new HashMap<>();
            map.put("vclN", requestObject.getPlateNum());
            map.put("vco", requestObject.getPlateColor());
            map.put("uid", uid);
            String sign = ApiDigestUtil.execute(map, key, DigestALGEnum.MD5, "UTF-8");
            log.info("生成sign签名:{}", sign);
            map.put("sign", sign);
            MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
            String jsonStr = objectMapper.writeValueAsString(map);
            log.info("truckInfoQuery请求上游参数:{}", jsonStr);

            RequestBody requestBody = RequestBody.create(mediaType, jsonStr);
            Request okRequest = new Request.Builder().post(requestBody).url(carCondition).build();
            OkHttpClient client = okHttpClient.newBuilder()
                    .sslSocketFactory(RxUtil.createSSLSocketFactory(), new RxUtil.TrustAllManager())
                    .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                    .readTimeout(outTime, TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime, TimeUnit.MILLISECONDS)
                    .build();
            Response response = client.newCall(okRequest).execute();
            String responseContext = "";
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            log.info("truckInfoQuery返回结果:{}", responseContext);
            TruckInfoQueryResponseObject responseObject = objectMapper.readValue(responseContext,
                    TruckInfoQueryResponseObject.class);
            response.close();
            if (responseObject != null) {
                upstreamCode = responseObject.getCode();
                ret.setCode(Constant.SUCCESS);
                setTruckInfoQueryResponse(ret, returnType, responseObject);
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            log.info("supplier10000041.truckInfoQuery接口-SocketTimeoutException：{}", ste);
            ErrorUtils.captureException(ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch (Exception ioe) {
            log.info("supplier10000041.truckInfoQuery接口-Exception：{}", ioe);
            ErrorUtils.captureException(ioe);
            ret.setCode(Constant.FAIL);
        }
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private boolean validateRequestParams(ChannelTypeHandleResponseObject ret, String returnType,
                                          TruckInfoQueryRequestObject requestObject) {
        if (!validateParamNullValue(requestObject)) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            }
            return false;
        } else if (StringUtils.isBlank(requestObject.getPlateNum())
                || !PatternTools.checkResult(Constant.PATTERN_CAR_NUMBER_REGEX, requestObject.getPlateNum())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(SjjhConstants.PARA_CHECK_CAR_NUMBER_FAIL_TEXT);
            ret.setResultBody(SjjhConstants.PARA_CHECK_CAR_NUMBER_FAIL_TEXT);
            return false;
        } else if (StringUtils.isBlank(requestObject.getPlateColor())
                || (!requestObject.getPlateColor().equals("1") && !requestObject.getPlateColor().equals("2"))) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(SjjhConstants.ERROR_PLATE_COLOR);
            ret.setResultBody(SjjhConstants.ERROR_PLATE_COLOR);
            return false;
        } else {
            return true;
        }
    }

    private void setTruckInfoQueryResponse(ChannelTypeHandleResponseObject ret, String returnType,
                                           TruckInfoQueryResponseObject responseObject) {
        boolean isCharge = responseObject != null
                && "0000".equals(responseObject.getCode());
        if (isCharge) {
            ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
        }
        if (responseObject != null
                && "0000".equals(responseObject.getCode())) {
            ret.setResultBody(JSON.toJSONString(responseObject.getData()));
            ret.setResultDesc(Constant.QUERY_SUCCESS);
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
            } else {
                ret.setResultCode(Constant.MATCH_CODE);
            }
        } else if (responseObject != null
                && "0001".equals(responseObject.getCode())) {
            // 查询成功，查无结果
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
            } else {
                ret.setResultCode(Constant.UN_FIND_NUM_CODE);
            }
            ret.setResultBody(SjjhConstants.NO_RESULT);
            ret.setResultDesc(SjjhConstants.NO_RESULT);
        } else if (responseObject != null
                && ("0002".equals(responseObject.getCode()) || "1000".equals(responseObject.getCode()))) {
            // 参数错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            } else {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
        } else {
            // 查询错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
            } else {
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
            }
            ret.setResultBody(Constant.OTHER_ERROR);
            ret.setResultDesc(Constant.OTHER_ERROR);
        }
    }

    @Override
    public ChannelTypeHandleResponseObject carOperationInfoQuery(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        if (outTime <= SjjhConstants.PARA_ZERO) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }
        log.info("supplier10000041.carOperationInfoQuery---customBody={},outTime={}", customBody, outTime);
        try {
            CarOperationInfoRequestObject requestObject = objectMapper.readValue(customBody,
                    CarOperationInfoRequestObject.class);
            log.info("supplier10000041.carOperationInfoQuery---requestObject={}", requestObject);
            // 参数校验
            if (!validateRequestParams(ret, returnType, requestObject)) {
                ret.setCode(Constant.SUCCESS);
                request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
                return ret;
            }

            //生成签名
            Map<String, String> map = new HashMap<>();
            map.put("vclN", requestObject.getPlateNum());
            map.put("vco", requestObject.getPlateColor());
            map.put("month", requestObject.getMonth());
            map.put("uid", uid);
            String sign = ApiDigestUtil.execute(map, key, DigestALGEnum.MD5, "UTF-8");
            log.info("生成sign签名:{}", sign);
            map.put("sign", sign);
            MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
            String jsonStr = objectMapper.writeValueAsString(map);
            log.info("carOperationInfoQuery请求上游参数:{}", jsonStr);

            RequestBody requestBody = RequestBody.create(mediaType, jsonStr);
            Request okRequest = new Request.Builder().post(requestBody).url(carOperate).build();
            OkHttpClient client = okHttpClient.newBuilder()
                    .sslSocketFactory(RxUtil.createSSLSocketFactory(), new RxUtil.TrustAllManager())
                    .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                    .readTimeout(outTime, TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime, TimeUnit.MILLISECONDS)
                    .build();
            Response response = client.newCall(okRequest).execute();
            String responseContext = "";
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            log.info("carOperationInfoQuery返回结果:{}", responseContext);
            CarOperationInfoResponseObject responseObject = objectMapper.readValue(responseContext,
                    CarOperationInfoResponseObject.class);
            response.close();
            if (responseObject != null) {
                upstreamCode = responseObject.getCode();
                ret.setCode(Constant.SUCCESS);
                setCarOperationInfoResponse(ret, returnType, responseObject);
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            log.info("supplier10000041.carOperationInfoQuery接口-SocketTimeoutException：{}", ste);
            ErrorUtils.captureException(ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch (Exception ioe) {
            log.info("supplier10000041.carOperationInfoQuery接口-Exception：{}", ioe);
            ErrorUtils.captureException(ioe);
            ret.setCode(Constant.FAIL);
        }
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private boolean validateRequestParams(ChannelTypeHandleResponseObject ret, String returnType,
                                          CarOperationInfoRequestObject requestObject) {
        Pattern pattern = Pattern.compile(SjjhConstants.MONTH_REGEX);
        if (!validateParamNullValue(requestObject)) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            }
            return false;
        } else if (StringUtils.isBlank(requestObject.getPlateNum())
                || !PatternTools.checkResult(Constant.PATTERN_CAR_NUMBER_REGEX, requestObject.getPlateNum())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(SjjhConstants.PARA_CHECK_CAR_NUMBER_FAIL_TEXT);
            ret.setResultBody(SjjhConstants.PARA_CHECK_CAR_NUMBER_FAIL_TEXT);
            return false;
        } else if (StringUtils.isBlank(requestObject.getPlateColor())
                || (!requestObject.getPlateColor().equals("1") && !requestObject.getPlateColor().equals("2"))) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(SjjhConstants.ERROR_PLATE_COLOR);
            ret.setResultBody(SjjhConstants.ERROR_PLATE_COLOR);
            return false;
        } else if (StringUtils.isBlank(requestObject.getMonth())
                || !pattern.matcher(requestObject.getMonth()).matches()) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            return false;
        } else {
            return true;
        }
    }

    private void setCarOperationInfoResponse(ChannelTypeHandleResponseObject ret, String returnType,
                                             CarOperationInfoResponseObject responseObject) {
        boolean isCharge = responseObject != null
                && "0000".equals(responseObject.getCode());
        if (isCharge) {
            ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
        }
        if (responseObject != null
                && "0000".equals(responseObject.getCode())) {
            ret.setResultBody(JSON.toJSONString(responseObject.getData()));
            ret.setResultDesc(Constant.QUERY_SUCCESS);
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
            } else {
                ret.setResultCode(Constant.MATCH_CODE);
            }
        } else if (responseObject != null
                && "0001".equals(responseObject.getCode())) {
            // 查询成功，查无结果
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
            } else {
                ret.setResultCode(Constant.UN_FIND_NUM_CODE);
            }
            ret.setResultBody(SjjhConstants.NO_RESULT);
            ret.setResultDesc(SjjhConstants.NO_RESULT);
        } else if (responseObject != null
                && ("0002".equals(responseObject.getCode()) || "1000".equals(responseObject.getCode()))) {
            // 参数错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            } else {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
        } else {
            // 查询错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
            } else {
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
            }
            ret.setResultBody(Constant.OTHER_ERROR);
            ret.setResultDesc(Constant.OTHER_ERROR);
        }
    }

    @Override
    public ChannelTypeHandleResponseObject carPicTransportNoQuery(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        if (outTime <= SjjhConstants.PARA_ZERO) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }
        log.info("supplier10000041.carPicTransportNoQuery---customBody={},outTime={}", customBody, outTime);
        try {
            CarPicTransportNoRequestObject requestObject = objectMapper.readValue(customBody,
                    CarPicTransportNoRequestObject.class);
            log.info("supplier10000041.carPicTransportNoQuery---requestObject={}", requestObject);
            // 参数校验
            if (!validateRequestParams(ret, returnType, requestObject)) {
                ret.setCode(Constant.SUCCESS);
                request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
                return ret;
            }

            //生成签名
            Map<String, String> map = new HashMap<>();
            map.put("vclN", requestObject.getPlateNum());
            map.put("vco", requestObject.getPlateColor());
            map.put("uid", uid);
            String sign = ApiDigestUtil.execute(map, key, DigestALGEnum.MD5, "UTF-8");
            log.info("生成sign签名:{}", sign);
            map.put("sign", sign);
            MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
            String jsonStr = objectMapper.writeValueAsString(map);
            log.info("carPicTransportNoQuery请求上游参数:{}", jsonStr);

            RequestBody requestBody = RequestBody.create(mediaType, jsonStr);
            Request okRequest = new Request.Builder().post(requestBody).url(carpictransportno).build();
            OkHttpClient client = okHttpClient.newBuilder()
                    .sslSocketFactory(RxUtil.createSSLSocketFactory(), new RxUtil.TrustAllManager())
                    .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                    .readTimeout(outTime, TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime, TimeUnit.MILLISECONDS)
                    .build();
            Response response = client.newCall(okRequest).execute();
            String responseContext = "";
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            log.info("carPicTransportNoQuery返回结果:{}", responseContext);
            CarPicTransportNoResponseObject responseObject = objectMapper.readValue(responseContext,
                    CarPicTransportNoResponseObject.class);
            response.close();
            if (responseObject != null) {
                upstreamCode = responseObject.getCode();
                ret.setCode(Constant.SUCCESS);
                setCarPicTransportNoResponse(ret, returnType, responseObject);
                if (ret.getIsCharge() == Constant.IS_CHARGE) {
                    chargeHandle(request, ret, requestObject);
                }
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            log.info("supplier10000041.carPicTransportNoQuery接口-SocketTimeoutException：{}", ste);
            ErrorUtils.captureException(ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch (Exception ioe) {
            log.info("supplier10000041.carPicTransportNoQuery接口-Exception：{}", ioe);
            ErrorUtils.captureException(ioe);
            ret.setCode(Constant.FAIL);
        }
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private boolean validateRequestParams(ChannelTypeHandleResponseObject ret, String returnType,
                                          CarPicTransportNoRequestObject requestObject) {
        if (!validateParamNullValue(requestObject)) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            }
            return false;
        } else if (StringUtils.isBlank(requestObject.getPlateNum())
                || !PatternTools.checkResult(Constant.PATTERN_CAR_NUMBER_REGEX, requestObject.getPlateNum())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(SjjhConstants.PARA_CHECK_CAR_NUMBER_FAIL_TEXT);
            ret.setResultBody(SjjhConstants.PARA_CHECK_CAR_NUMBER_FAIL_TEXT);
            return false;
        } else if (StringUtils.isBlank(requestObject.getPlateColor())
                || (!requestObject.getPlateColor().equals("1") && !requestObject.getPlateColor().equals("2"))) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(SjjhConstants.ERROR_PLATE_COLOR);
            ret.setResultBody(SjjhConstants.ERROR_PLATE_COLOR);
            return false;
        } else {
            return true;
        }
    }

    private void setCarPicTransportNoResponse(ChannelTypeHandleResponseObject ret, String returnType,
                                              CarPicTransportNoResponseObject responseObject) {
        boolean isCharge = responseObject != null
                && "0000".equals(responseObject.getCode());
        if (isCharge) {
            ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
        }
        if (responseObject != null
                && "0000".equals(responseObject.getCode())) {
            ret.setResultBody(JSON.toJSONString(responseObject.getData()));
            ret.setResultDesc(Constant.QUERY_SUCCESS);
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
            } else {
                ret.setResultCode(Constant.MATCH_CODE);
            }
        } else if (responseObject != null
                && "0001".equals(responseObject.getCode())) {
            // 查询成功，查无结果
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
            } else {
                ret.setResultCode(Constant.UN_FIND_NUM_CODE);
            }
            ret.setResultBody(SjjhConstants.NO_RESULT);
            ret.setResultDesc(SjjhConstants.NO_RESULT);
        } else if (responseObject != null
                && ("0002".equals(responseObject.getCode()) || "1000".equals(responseObject.getCode()))) {
            // 参数错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            } else {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
        } else {
            // 查询错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
            } else {
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
            }
            ret.setResultBody(Constant.OTHER_ERROR);
            ret.setResultDesc(Constant.OTHER_ERROR);
        }
    }

    public void chargeHandle(HttpServletRequest request, ChannelTypeHandleResponseObject ret,
                             CarPicTransportNoRequestObject requestObject) throws ParseException {

        String userId = request.getHeader(SjjhConstants.USERID_HEADER_KEY);
        String channelId = request.getHeader(SjjhConstants.CHANNELID_HEADER_KEY);
        SimpleDateFormat daySdf = new SimpleDateFormat("yyyyMMdd");
        Date current = new Date();
        String dayTime = daySdf.format(current.getTime());

        String redisDateKey = userId + "_" + channelId + "_" + requestObject.getPlateNum() + "_" + requestObject.getPlateColor() + "_" + dayTime;
        if (!stringRedisTemplate.boundValueOps(redisDateKey).setIfAbsent("1")) {
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
        } else {
            stringRedisTemplate.boundValueOps(redisDateKey).expire(1, TimeUnit.DAYS);
        }
    }

    @Override
    public ChannelTypeHandleResponseObject carMileageQuery(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        if (outTime <= SjjhConstants.PARA_ZERO) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }
        log.info("supplier10000041.carMileageQuery---customBody={},outTime={}", customBody, outTime);
        try {
            CarMileageQueryRequestObject requestObject = objectMapper.readValue(customBody,
                    CarMileageQueryRequestObject.class);
            log.info("supplier10000041.carMileageQuery---requestObject={}", requestObject);
            // 参数校验
            if (!validateRequestParams(ret, returnType, requestObject)) {
                ret.setCode(Constant.SUCCESS);
                request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
                return ret;
            }

            //生成签名
            Map<String, String> map = new HashMap<>();
            map.put("vclN", requestObject.getPlateNum());
            map.put("vco", requestObject.getPlateColor());
            map.put("queryTime", requestObject.getTime());
            map.put("uid", uid);
            String sign = ApiDigestUtil.execute(map, key, DigestALGEnum.MD5, "UTF-8");
            log.info("生成sign签名:{}", sign);
            map.put("sign", sign);
            MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
            String jsonStr = objectMapper.writeValueAsString(map);
            log.info("carMileageQuery请求上游参数:{}", jsonStr);

            RequestBody requestBody = RequestBody.create(mediaType, jsonStr);
            Request okRequest = new Request.Builder().post(requestBody).url(vQueryMileage).build();
            OkHttpClient client = okHttpClient.newBuilder()
                    .sslSocketFactory(RxUtil.createSSLSocketFactory(), new RxUtil.TrustAllManager())
                    .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                    .readTimeout(outTime, TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime, TimeUnit.MILLISECONDS)
                    .build();
            Response response = client.newCall(okRequest).execute();
            String responseContext = "";
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            log.info("carMileageQuery返回结果:{}", responseContext);
            CarMileageQueryResponseObject responseObject = objectMapper.readValue(responseContext,
                    CarMileageQueryResponseObject.class);
            response.close();
            if (responseObject != null) {
                upstreamCode = responseObject.getCode();
                ret.setCode(Constant.SUCCESS);
                setCarMileageQueryResponse(ret, returnType, responseObject);
                if (ret.getIsCharge() == Constant.IS_CHARGE) {
                    chargeHandle(request, ret, requestObject);
                }
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            log.info("supplier10000041.carMileageQuery接口-SocketTimeoutException：{}", ste);
            ErrorUtils.captureException(ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch (Exception ioe) {
            log.info("supplier10000041.carMileageQuery接口-Exception：{}", ioe);
            ErrorUtils.captureException(ioe);
            ret.setCode(Constant.FAIL);
        }
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private boolean validateRequestParams(ChannelTypeHandleResponseObject ret, String returnType,
                                          CarMileageQueryRequestObject requestObject) {
        Pattern pattern = Pattern.compile(SjjhConstants.DATE_REGEX);
        if (!validateParamNullValue(requestObject)) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            }
            return false;
        } else if (StringUtils.isBlank(requestObject.getPlateNum())
                || !PatternTools.checkResult(Constant.PATTERN_CAR_NUMBER_REGEX, requestObject.getPlateNum())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(SjjhConstants.PARA_CHECK_CAR_NUMBER_FAIL_TEXT);
            ret.setResultBody(SjjhConstants.PARA_CHECK_CAR_NUMBER_FAIL_TEXT);
            return false;
        } else if (StringUtils.isBlank(requestObject.getPlateColor())
                || (!requestObject.getPlateColor().equals("1") && !requestObject.getPlateColor().equals("2"))) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(SjjhConstants.ERROR_PLATE_COLOR);
            ret.setResultBody(SjjhConstants.ERROR_PLATE_COLOR);
            return false;
        } else if (StringUtils.isBlank(requestObject.getTime())
                || !pattern.matcher(requestObject.getTime()).matches()) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            return false;
        } else {
            return true;
        }
    }

    private void setCarMileageQueryResponse(ChannelTypeHandleResponseObject ret, String returnType,
                                            CarMileageQueryResponseObject responseObject) {
        boolean isCharge = responseObject != null
                && "0000".equals(responseObject.getCode());
        if (isCharge) {
            ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
        }
        if (responseObject != null
                && "0000".equals(responseObject.getCode())) {
            ret.setResultBody(JSON.toJSONString(responseObject.getData()));
            ret.setResultDesc(Constant.QUERY_SUCCESS);
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
            } else {
                ret.setResultCode(Constant.MATCH_CODE);
            }
        } else if (responseObject != null
                && "0001".equals(responseObject.getCode())) {
            // 查询成功，查无结果
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
            } else {
                ret.setResultCode(Constant.UN_FIND_NUM_CODE);
            }
            ret.setResultBody(SjjhConstants.NO_RESULT);
            ret.setResultDesc(SjjhConstants.NO_RESULT);
        } else if (responseObject != null
                && ("0002".equals(responseObject.getCode()) || "1000".equals(responseObject.getCode()))) {
            // 参数错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            } else {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
        } else {
            // 查询错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
            } else {
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
            }
            ret.setResultBody(Constant.OTHER_ERROR);
            ret.setResultDesc(Constant.OTHER_ERROR);
        }
    }

    private void chargeHandle(HttpServletRequest request, ChannelTypeHandleResponseObject ret,
                             CarMileageQueryRequestObject requestObject) {
        String monthLimit = request.getHeader(Constant.MONTH_CHARGE_LIMIT);
        log.info("monthLimit:{}", monthLimit);
        if ((monthLimit == null || "".equals(monthLimit))) {
            log.error("没有设置包月和包日标志位,month_limit:{}", monthLimit);
            return;
        }
        int monthCount = Integer.parseInt(monthLimit);
        String userId = request.getHeader(SjjhConstants.USERID_HEADER_KEY);
        String channelId = request.getHeader(SjjhConstants.CHANNELID_HEADER_KEY);
        SimpleDateFormat monthSdf = new SimpleDateFormat("yyyyMM");
        Date current = new Date();
        String monthTime = monthSdf.format(current.getTime());

        long redisMonthCount = 0;
        if (monthCount != -1) {
            redisMonthCount = stringRedisTemplate.boundHashOps(SjjhConstants.MONTH_CHARGE_COUNT)
                    .increment(userId + "_" + channelId + "_" + requestObject.getPlateNum() + "_" + requestObject.getPlateColor() + "_" + monthTime, 1);
            if (redisMonthCount == 1) {
                Calendar cal = Calendar.getInstance();
                cal.setTime(current);
                int lastDay = cal.getActualMaximum(Calendar.DAY_OF_MONTH);
                cal.set(Calendar.DAY_OF_MONTH, lastDay);
                cal.set(Calendar.HOUR_OF_DAY, 23);
                cal.set(Calendar.MINUTE, 59);
                cal.set(Calendar.SECOND, 59);
                stringRedisTemplate.boundHashOps(SjjhConstants.MONTH_CHARGE_COUNT).expireAt(cal.getTime());
            }
        }
        if (monthCount != -1 && redisMonthCount > monthCount) {
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            return;
        }
    }

    @Override
    public ChannelTypeHandleResponseObject carParkingInfoQuery(HttpServletRequest request, String customBody, int outTime) {
        ChannelTypeHandleResponseObject ret = new ChannelTypeHandleResponseObject();
        ret.setIsCharge(Constant.INTERFACE_QUERY_NO_FEE);
        String upstreamCode = "" + Constant.LOG_UPSTREAM_DEFAULT_RESPONSE_CODE;
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        String returnType = request.getHeader(Constant.CUSTOMER_RETURN_TYPE_PARA);
        if (StringUtils.isBlank(returnType)) {
            returnType = Constant.CUSTOMER_RETURN_ZW;
        }
        if (outTime <= SjjhConstants.PARA_ZERO) {
            outTime = Constant.HTTPCLIENT_CONNECTTIMEOUT;
        }
        log.info("supplier10000041.carParkingInfoQuery---customBody={},outTime={}", customBody, outTime);
        try {
            CarParkingInfoRequestObject requestObject = objectMapper.readValue(customBody,
                    CarParkingInfoRequestObject.class);
            log.info("supplier10000041.carParkingInfoQuery---requestObject={}", requestObject);
            // 参数校验
            if (!validateRequestParams(ret, returnType, requestObject)) {
                ret.setCode(Constant.SUCCESS);
                request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
                return ret;
            }

            //生成签名
            Map<String, String> map = new HashMap<>();
            map.put("vclN", requestObject.getPlateNum());
            map.put("vco", requestObject.getPlateColor());
            map.put("queryTime", requestObject.getTime());
            if (StringUtils.isNotBlank(requestObject.getParkingMinutes())) {
                map.put("parkMins", requestObject.getParkingMinutes());
            }
            map.put("uid", uid);
            String sign = ApiDigestUtil.execute(map, key, DigestALGEnum.MD5, "UTF-8");
            log.info("生成sign签名:{}", sign);
            map.put("sign", sign);
            MediaType mediaType = MediaType.parse(org.springframework.http.MediaType.APPLICATION_JSON_UTF8_VALUE);
            String jsonStr = objectMapper.writeValueAsString(map);
            log.info("carParkingInfoQuery请求上游参数:{}", jsonStr);

            RequestBody requestBody = RequestBody.create(mediaType, jsonStr);
            Request okRequest = new Request.Builder().post(requestBody).url(vQueryPark).build();
            OkHttpClient client = okHttpClient.newBuilder()
                    .sslSocketFactory(RxUtil.createSSLSocketFactory(), new RxUtil.TrustAllManager())
                    .connectTimeout(outTime, TimeUnit.MILLISECONDS)
                    .readTimeout(outTime, TimeUnit.MILLISECONDS)
                    .writeTimeout(outTime, TimeUnit.MILLISECONDS)
                    .build();
            Response response = client.newCall(okRequest).execute();
            String responseContext = "";
            if (response.body() != null) {
                responseContext = response.body().string();
            }
            log.info("carParkingInfoQuery返回结果:{}", responseContext);
            CarParkingInfoResponseObject responseObject = objectMapper.readValue(responseContext,
                    CarParkingInfoResponseObject.class);
            response.close();
            if (responseObject != null) {
                upstreamCode = responseObject.getCode();
                ret.setCode(Constant.SUCCESS);
                setCarParkingInfoResponse(ret, returnType, responseObject);
                if (ret.getIsCharge() == Constant.IS_CHARGE) {
                    chargeHandle(request, ret, requestObject);
                }
            } else {
                ret.setCode(Constant.FAIL);
            }
        } catch (SocketTimeoutException ste) {
            log.info("supplier10000041.carParkingInfoQuery接口-SocketTimeoutException：{}", ste);
            ErrorUtils.captureException(ste);
            ret.setCode(Constant.REQUEST_TIMEOUT);
        } catch (Exception ioe) {
            log.info("supplier10000041.carParkingInfoQuery接口-Exception：{}", ioe);
            ErrorUtils.captureException(ioe);
            ret.setCode(Constant.FAIL);
        }
        request.setAttribute(Constant.LOG_UPSTREAM_RESPONSE_CODE, upstreamCode);
        return ret;
    }

    private boolean validateRequestParams(ChannelTypeHandleResponseObject ret, String returnType,
                                          CarParkingInfoRequestObject requestObject) {
        Pattern pattern = Pattern.compile(SjjhConstants.DATE_REGEX);
        if (!validateParamNullValue(requestObject)) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
                ret.setResultBody(Constant.PARAMETER_NAME_ERROR);
                ret.setResultDesc(Constant.PARAMETER_NAME_ERROR);
            }
            return false;
        } else if (StringUtils.isBlank(requestObject.getPlateNum())
                || !PatternTools.checkResult(Constant.PATTERN_CAR_NUMBER_REGEX, requestObject.getPlateNum())) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(SjjhConstants.PARA_CHECK_CAR_NUMBER_FAIL_TEXT);
            ret.setResultBody(SjjhConstants.PARA_CHECK_CAR_NUMBER_FAIL_TEXT);
            return false;
        } else if (StringUtils.isBlank(requestObject.getPlateColor())
                || (!requestObject.getPlateColor().equals("1") && !requestObject.getPlateColor().equals("2"))) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(SjjhConstants.ERROR_PLATE_COLOR);
            ret.setResultBody(SjjhConstants.ERROR_PLATE_COLOR);
            return false;
        } else if (StringUtils.isBlank(requestObject.getTime())
                || !pattern.matcher(requestObject.getTime()).matches()) {
            if (Constant.CUSTOMER_RETURN_ZW.equals(returnType)) {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            } else {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            }
            ret.setResultDesc(Constant.INVALID_PARAMETER);
            ret.setResultBody(Constant.INVALID_PARAMETER);
            return false;
        } else {
            return true;
        }
    }

    private void setCarParkingInfoResponse(ChannelTypeHandleResponseObject ret, String returnType,
                                           CarParkingInfoResponseObject responseObject) {
        boolean isCharge = responseObject != null
                && "0000".equals(responseObject.getCode());
        if (isCharge) {
            ret.setIsCharge(Constant.INTERFACE_QUERY_FEE);
        }
        if (responseObject != null
                && "0000".equals(responseObject.getCode())) {
            ret.setResultBody(JSON.toJSONString(responseObject.getData()));
            ret.setResultDesc(Constant.QUERY_SUCCESS);
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_MATCH);
            } else {
                ret.setResultCode(Constant.MATCH_CODE);
            }
        } else if (responseObject != null
                && "0001".equals(responseObject.getCode())) {
            // 查询成功，查无结果
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_NO_INFO);
            } else {
                ret.setResultCode(Constant.UN_FIND_NUM_CODE);
            }
            ret.setResultBody(SjjhConstants.NO_RESULT);
            ret.setResultDesc(SjjhConstants.NO_RESULT);
        } else if (responseObject != null
                && ("0002".equals(responseObject.getCode()) || "1000".equals(responseObject.getCode()))) {
            // 参数错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_INVALID_PARAMETER);
            } else {
                ret.setResultCode(Constant.INVALID_PARAMETER_CODE);
            }
            ret.setResultBody(Constant.INVALID_PARAMETER);
            ret.setResultDesc(Constant.INVALID_PARAMETER);
        } else {
            // 查询错误
            if (Constant.CUSTOMER_RETURN_JK.equals(returnType)) {
                ret.setResultCode(Constant.JK_RETURN_CODE_OTHER_ERROR);
            } else {
                ret.setResultCode(Constant.OTHER_ERROR_CODE);
            }
            ret.setResultBody(Constant.OTHER_ERROR);
            ret.setResultDesc(Constant.OTHER_ERROR);
        }
    }

    private void chargeHandle(HttpServletRequest request, ChannelTypeHandleResponseObject ret,
                              CarParkingInfoRequestObject requestObject) {
        String monthLimit = request.getHeader(Constant.MONTH_CHARGE_LIMIT);
        log.info("monthLimit:{}", monthLimit);
        if ((monthLimit == null || "".equals(monthLimit))) {
            log.error("没有设置包月和包日标志位,month_limit:{}", monthLimit);
            return;
        }
        int monthCount = Integer.parseInt(monthLimit);
        String userId = request.getHeader(SjjhConstants.USERID_HEADER_KEY);
        String channelId = request.getHeader(SjjhConstants.CHANNELID_HEADER_KEY);
        SimpleDateFormat monthSdf = new SimpleDateFormat("yyyyMM");
        Date current = new Date();
        String monthTime = monthSdf.format(current.getTime());

        long redisMonthCount = 0;
        if (monthCount != -1) {
            redisMonthCount = stringRedisTemplate.boundHashOps(SjjhConstants.MONTH_CHARGE_COUNT)
                    .increment(userId + "_" + channelId + "_" + requestObject.getPlateNum() + "_" + requestObject.getPlateColor() + "_" + monthTime, 1);
            if (redisMonthCount == 1) {
                Calendar cal = Calendar.getInstance();
                cal.setTime(current);
                int lastDay = cal.getActualMaximum(Calendar.DAY_OF_MONTH);
                cal.set(Calendar.DAY_OF_MONTH, lastDay);
                cal.set(Calendar.HOUR_OF_DAY, 23);
                cal.set(Calendar.MINUTE, 59);
                cal.set(Calendar.SECOND, 59);
                stringRedisTemplate.boundHashOps(SjjhConstants.MONTH_CHARGE_COUNT).expireAt(cal.getTime());
            }
        }
        if (monthCount != -1 && redisMonthCount > monthCount) {
            ret.setIsCharge(Constant.IS_NOT_CHARGE);
            return;
        }
    }
}
